<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\woddingat\Customizer\Settings;

use radiustheme\woddingat\Customizer\RDTheme_Customizer;
use radiustheme\woddingat\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\woddingat\Customizer\Controls\Customizer_Image_Radio_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Blog_Post_Settings extends RDTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_blog_post_controls' ) );
	}

    /**
     * Blog Post Controls
     */
    public function register_blog_post_controls( $wp_customize ) {

        // Blog Post Style
        $wp_customize->add_setting( 'blog_style',
            array(
                'default' => $this->defaults['blog_style'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );

        $wp_customize->add_control( new Customizer_Image_Radio_Control( $wp_customize, 'blog_style',
            array(
                'label' => __( 'Post Layout', 'woddingat' ),
                'description' => esc_html__( 'Blog Post layout variation you can selecr and use.', 'woddingat' ),
                'section' => 'blog_post_settings_section',
                'choices' => array(
                    '1' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/blog2.jpg',
                        'name' => __( 'Layout 1', 'woddingat' )
                    ),
                    '2' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/blog1.jpg',
                        'name' => __( 'Layout 2', 'woddingat' )
                    )
                )
            )
        ) );

        // Post Category
        $wp_customize->add_setting( 'blog_cats',
            array(
                'default' => $this->defaults['blog_cats'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'blog_cats',
            array(
                'label' => __( 'Display Category', 'woddingat' ),
                'section' => 'blog_post_settings_section',
            )
        ) );

        // Post Date
        $wp_customize->add_setting( 'blog_date',
            array(
                'default' => $this->defaults['blog_date'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'blog_date',
            array(
                'label' => __( 'Display Date', 'woddingat' ),
                'section' => 'blog_post_settings_section',
            )
        ));

        // Comments
        $wp_customize->add_setting( 'blog_meta_comments',
            array(
                'default' => $this->defaults['blog_meta_comments'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'blog_meta_comments',
            array(
                'label' => __( 'Display Comments', 'woddingat' ),
                'section' => 'blog_post_settings_section',
            )
        ) );
        // Quote Post
        $wp_customize->add_setting( 'blog_quote_post',
            array(
                'default' => $this->defaults['blog_quote_post'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'blog_quote_post',
            array(
                'label' => __( 'Display Quote Post', 'woddingat' ),
                'section' => 'blog_post_settings_section',
            )
        ) );
        // Quote Author Name
        $wp_customize->add_setting( 'blog_quote_authname',
            array(
                'default'           => $this->defaults['blog_quote_authname'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'blog_quote_authname',
            array(
                'label'           => __( 'Quote Author Name', 'woddingat' ),
                'section'         => 'blog_post_settings_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_quote_post_enabled',
            )
        );
        // Quote Author Name
        $wp_customize->add_setting( 'blog_quote_authdesi',
            array(
                'default'           => $this->defaults['blog_quote_authdesi'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'blog_quote_authdesi',
            array(
                'label'           => __( 'Quote Author Designation', 'woddingat' ),
                'section'         => 'blog_post_settings_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_quote_post_enabled',
            )
        );
        // Link Post
        $wp_customize->add_setting( 'blog_link_post',
            array(
                'default' => $this->defaults['blog_link_post'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'blog_link_post',
            array(
                'label' => __( 'Display Link Post', 'woddingat' ),
                'section' => 'blog_post_settings_section',
                'active_callback' => 'rttheme_is_blog_style2_enabled',
            )
        ) );
        // Excerpt
        $wp_customize->add_setting( 'blog_excerpt',
            array(
                'default' => $this->defaults['blog_excerpt'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'blog_excerpt',
            array(
                'label' => __( 'Display Excerpt', 'woddingat' ),
                'section' => 'blog_post_settings_section',
                'active_callback' => 'rttheme_is_blog_style1_enabled',
            )
        ) );
        // Excerpt Length
        $wp_customize->add_setting( 'excerpt_length',
            array(
                'default' => $this->defaults['excerpt_length'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer'
            )
        );
        $wp_customize->add_control( 'excerpt_length',
            array(
                'label' => __( 'Excerpt Length', 'woddingat' ),
                'section' => 'blog_post_settings_section',
                'type' => 'number',
                'active_callback' => 'rttheme_is_blog_style1_enabled',
            )
        );
        // Readmore
        $wp_customize->add_setting( 'blog_readmore',
            array(
                'default' => $this->defaults['blog_readmore'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'blog_readmore',
            array(
                'label' => __( 'Display Readmore', 'woddingat' ),
                'section' => 'blog_post_settings_section',
                'active_callback' => 'rttheme_is_blog_style1_enabled',
            )
        ) );

    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new RDTheme_Blog_Post_Settings();
}
