<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\woddingat\Customizer\Settings;

use radiustheme\woddingat\Customizer\RDTheme_Customizer;
use radiustheme\woddingat\Customizer\Controls\Customizer_Heading_Control2;
use radiustheme\woddingat\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\woddingat\Customizer\Controls\Customizer_Separator_Control;

use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Colors_Settings extends RDTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_colors_controls' ) );
	}

    public function register_colors_controls( $wp_customize ) {

        /*Global Color*/
        $wp_customize->add_setting('primary_color', 
            array(
                'default' => $this->defaults['primary_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'primary_color',
            array(
                'label' => esc_html__('Primary Color', 'salion'),
                'section' => 'color_section', 
            )
        ));
        
        $wp_customize->add_setting('secondary_color', 
            array(
                'default' => $this->defaults['secondary_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'secondary_color',
            array(
                'label' => esc_html__('Secondary Color', 'salion'),
                'section' => 'color_section', 
            )
        ));     
                
        $wp_customize->add_setting('body_color', 
            array(
                'default' => $this->defaults['body_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'body_color',
            array(
                'label' => esc_html__('Body Color', 'salion'),
                'section' => 'color_section', 
            )
        ));

        /**
         * Main Menu Heading
         */
        $wp_customize->add_setting('theme_menu_style', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control2($wp_customize, 'theme_menu_style', array(
            'label' => __( 'Menu Color Settings', 'woddingat' ),
            'section' => 'color_section',
        )));

        // Main Menu Font color
        $wp_customize->add_setting('menu_text_color', 
            array(
                'default' => $this->defaults['menu_text_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'menu_text_color',
            array(
                'label' => esc_html__('Text Color', 'woddingat'),
                'settings' => 'menu_text_color', 
                'priority' => 10, 
                'section' => 'color_section', 
            )
        ));

        // Menu Font hover color
        $wp_customize->add_setting('menu_text_hover_color', 
            array(
                'default' => $this->defaults['menu_text_hover_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'menu_text_hover_color',
            array(
                'label' => esc_html__( 'Hover Text Color', 'woddingat' ),
                'settings' => 'menu_text_hover_color', 
                'priority' => 10, 
                'section' => 'color_section',
            )
        ));

        // Menu active color
        $wp_customize->add_setting('menu_text_active_color', 
            array(
                'default' => $this->defaults['menu_text_active_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'menu_text_active_color',
            array(
                'label' => esc_html__( 'Active Text Color', 'woddingat' ),
                'settings' => 'menu_text_active_color', 
                'priority' => 10, 
                'section' => 'color_section',
            )
        ));


        /**
         * Sub Menu Heading
         */
        $wp_customize->add_setting('sub_menu_style', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control2($wp_customize, 'sub_menu_style', array(
            'label' => __( 'Sub Menu Color Settings', 'woddingat' ),
            'section' => 'color_section',
        )));


        // Sub Menu Font color
        $wp_customize->add_setting('sub_menu_text_color', 
            array(
                'default' => $this->defaults['sub_menu_text_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sub_menu_text_color',
            array(
                'label' => esc_html__('Text Color', 'woddingat'),
                'settings' => 'sub_menu_text_color', 
                'priority' => 10, 
                'section' => 'color_section',
            )
        ));

        // Menu Menu active color
        $wp_customize->add_setting('sub_menu_active_color', 
            array(
                'default' => $this->defaults['sub_menu_active_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sub_menu_active_color',
            array(
                'label' => esc_html__( 'Active Color', 'woddingat' ),
                'settings' => 'sub_menu_active_color', 
                'priority' => 10, 
                'section' => 'color_section',
            )
        ));

        // Sub Menu Font hover color
        $wp_customize->add_setting('sub_menu_text_hover_color', 
            array(
                'default' => $this->defaults['sub_menu_text_hover_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sub_menu_text_hover_color',
            array(
                'label' => esc_html__('Hover Text Color', 'woddingat'),
                'settings' => 'sub_menu_text_hover_color', 
                'priority' => 10, 
                'section' => 'color_section',
            )
        ));


        // Sub Menu Border color
        $wp_customize->add_setting('sub_menu_border_color', 
            array(
                'default' => $this->defaults['sub_menu_border_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sub_menu_border_color',
            array(
                'label' => esc_html__('Border Color', 'woddingat'),
                'settings' => 'sub_menu_border_color', 
                'priority' => 10, 
                'section' => 'color_section',
            )
        ));
        // Sub Menu Hover Border color
        $wp_customize->add_setting('sub_menu_hborder_color', 
            array(
                'default' => $this->defaults['sub_menu_hborder_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sub_menu_hborder_color',
            array(
                'label' => esc_html__('Hover Border Color', 'woddingat'),
                'settings' => 'sub_menu_hborder_color', 
                'priority' => 10, 
                'section' => 'color_section',
            )
        ));
        

    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new RDTheme_Colors_Settings();
}
