<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\woddingat\Customizer\Settings;

use radiustheme\woddingat\Customizer\RDTheme_Customizer;
use radiustheme\woddingat\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\woddingat\Customizer\Controls\Customizer_Separator_Control;
use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Error_Settings extends RDTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_error_controls' ) );
	}

    public function register_error_controls( $wp_customize ) {
        // Error Text
        $wp_customize->add_setting( 'error_text1',
            array(
                'default' => $this->defaults['error_text1'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization'
            )
        );
        $wp_customize->add_control( 'error_text1',
            array(
                'label' => __( 'Error Text 1', 'woddingat' ),
                'section' => 'error_section',
                'type' => 'text',
            )
        );
        // Error Text
        $wp_customize->add_setting( 'error_text2',
            array(
                'default' => $this->defaults['error_text2'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization'
            )
        );
        $wp_customize->add_control( 'error_text2',
            array(
                'label' => __( 'Error Text 2', 'woddingat' ),
                'section' => 'error_section',
                'type' => 'text',
            )
        );
        // Button Text
        $wp_customize->add_setting( 'error_buttontext',
            array(
                'default' => $this->defaults['error_buttontext'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization'
            )
        );
        $wp_customize->add_control( 'error_buttontext',
            array(
                'label' => __( 'Button Text', 'woddingat' ),
                'section' => 'error_section',
                'type' => 'text',
            )
        );
        // Error content
        $wp_customize->add_setting( 'error_content',
            array(
                'default'           => $this->defaults['error_content'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'error_content',
            array(
                'label'           => __( 'Error Content', 'woddingat' ),
                'section'         => 'error_section',
                'type'            => 'textarea',
            )
        );

        $wp_customize->add_setting('error_text1_color', 
            array(
                'default' => $this->defaults['error_text1_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'error_text1_color',
            array(
                'label' => esc_html__('Error Text 1 Color', 'woddingat'),
                'section' => 'error_section', 
            )
        ));
        
        $wp_customize->add_setting('error_text2_color', 
            array(
                'default' => $this->defaults['error_text2_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'error_text2_color',
            array(
                'label' => esc_html__('Error Text 2 Color', 'woddingat'),
                'section' => 'error_section', 
            )
        ));

        $wp_customize->add_setting('error_desc_color', 
            array(
                'default' => $this->defaults['error_desc_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'error_desc_color',
            array(
                'label' => esc_html__('Description Color', 'woddingat'),
                'section' => 'error_section', 
            )
        ));


        $wp_customize->add_setting('error_btnbg', 
            array(
                'default' => $this->defaults['error_btnbg'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'error_btnbg',
            array(
                'label' => esc_html__('Button Background Color', 'woddingat'),
                'section' => 'error_section', 
            )
        ));

        $wp_customize->add_setting('error_btntxt_color', 
            array(
                'default' => $this->defaults['error_btntxt_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'error_btntxt_color',
            array(
                'label' => esc_html__('Button Text Color', 'woddingat'),
                'section' => 'error_section', 
            )
        ));

    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new RDTheme_Error_Settings();
}
