<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\woddingat\Customizer\Settings;

use radiustheme\woddingat\Customizer\RDTheme_Customizer;
use radiustheme\woddingat\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\woddingat\Customizer\Controls\Customizer_Separator_Control;
use radiustheme\woddingat\Customizer\Controls\Customizer_Heading_Control;
use radiustheme\woddingat\Customizer\Controls\Customizer_Image_Radio_Control;
use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Footer_Settings extends RDTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_footer_controls' ) );
	}

    public function register_footer_controls( $wp_customize ) {

        // Footer Style
        $wp_customize->add_setting( 'footer_style',
            array(
                'default'           => $this->defaults['footer_style'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );
        $wp_customize->add_control( new Customizer_Image_Radio_Control( $wp_customize, 'footer_style',
            array(
                'label'       => __( 'Footer Layout', 'woddingat' ),
                'description' => esc_html__( 'You can override this settings only Mobile', 'woddingat' ),
                'section'     => 'footer_section',
                'choices'     => array(
                    '1' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/footer-1.jpg',
                        'name'  => __( 'Layout 1', 'woddingat' )
                    ),                  
                    '2' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/footer-2.jpg',
                        'name'  => __( 'Layout 2', 'woddingat' )
                    ),
                    '3' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/footer-3.jpg',
                        'name'  => __( 'Layout 3', 'woddingat' )
                    ),
                    '4' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/footer-4.jpg',
                        'name'  => __( 'Layout 4', 'woddingat' )
                    ),
                )
            )
        ) );        

        /**
        * Footer 1 Background
        ========================================================================================*/
        $wp_customize->add_setting('footer1_heading', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'footer1_heading', array(
            'label' => esc_html__( 'Footer 1 Background', 'woddingat' ),
            'section' => 'footer_section',
            'active_callback'   => 'rttheme_is_footer1_enabled',
        )));
        // Display Footer 1 Background Image
        $wp_customize->add_setting( 'display_footer1_bg_image',
            array(
                'default'           => $this->defaults['display_footer1_bg_image'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'display_footer1_bg_image',
            array(
                'label'           => __( 'Background Image', 'woddingat' ),
                'section'         => 'footer_section',
                'active_callback'   => 'rttheme_is_footer1_enabled',
            )
        ) );
        // Footer background image
        $wp_customize->add_setting( 'footer1_bg_img',
            array(
                'default' => $this->defaults['footer1_bg_img'],
                'transport' => 'refresh',
                'sanitize_callback' => 'absint',
            )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'footer1_bg_img',
            array(
                'label' => esc_html__( 'Background Image 1', 'woddingat' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'woddingat' ),
                'section' => 'footer_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => esc_html__( 'Select File', 'woddingat' ),
                    'change' => esc_html__( 'Change File', 'woddingat' ),
                    'default' => esc_html__( 'Default', 'woddingat' ),
                    'remove' => esc_html__( 'Remove', 'woddingat' ),
                    'placeholder' => esc_html__( 'No file selected', 'woddingat' ),
                    'frame_title' => esc_html__( 'Select File', 'woddingat' ),
                    'frame_button' => esc_html__( 'Choose File', 'woddingat' ),
                ),
                'active_callback'   => 'rttheme_is_footer1_enabled',
            )
        ) );
        $wp_customize->add_setting( 'footer1_bg_img2',
            array(
                'default' => $this->defaults['footer1_bg_img2'],
                'transport' => 'refresh',
                'sanitize_callback' => 'absint',
            )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'footer1_bg_img2',
            array(
                'label' => esc_html__( 'Background Image 2', 'woddingat' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'woddingat' ),
                'section' => 'footer_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => esc_html__( 'Select File', 'woddingat' ),
                    'change' => esc_html__( 'Change File', 'woddingat' ),
                    'default' => esc_html__( 'Default', 'woddingat' ),
                    'remove' => esc_html__( 'Remove', 'woddingat' ),
                    'placeholder' => esc_html__( 'No file selected', 'woddingat' ),
                    'frame_title' => esc_html__( 'Select File', 'woddingat' ),
                    'frame_button' => esc_html__( 'Choose File', 'woddingat' ),
                ),
                'active_callback'   => 'rttheme_is_footer1_enabled',
            )
        ) );
        // Banner background color
        $wp_customize->add_setting('footer1_bg_color', 
            array(
                'default' => $this->defaults['footer1_bg_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer1_bg_color',
            array(
                'label' => esc_html__('Background Color', 'woddingat'),
                'settings' => 'footer1_bg_color', 
                'priority' => 10, 
                'section' => 'footer_section', 
                'active_callback'   => 'rttheme_is_footer1_enabled',
            )
        ));
        // Banner background color opacity
        $wp_customize->add_setting( 'footer1_bg_opacity',
            array(
                'default' => $this->defaults['footer1_bg_opacity'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
            )
        );
        $wp_customize->add_control( 'footer1_bg_opacity',
            array(
                'label' => esc_html__( 'Background Opacity', 'woddingat' ),
                'section' => 'footer_section',
                'type' => 'number',
                'active_callback'   => 'rttheme_is_footer1_enabled',
            )
        );
         // Footer 1 padding top
        $wp_customize->add_setting( 'footer1_padding_top',
            array(
                'default' => $this->defaults['footer1_padding_top'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
            )
        );
        $wp_customize->add_control( 'footer1_padding_top',
            array(
                'label' => __( 'Padding Top', 'woddingat' ),
                'section' => 'footer_section',
                'type' => 'number',
                'active_callback' => 'rttheme_is_footer1_enabled',
            )
        );
        // Footer 1 padding bottom
        $wp_customize->add_setting( 'footer1_padding_bottom',
            array(
                'default' => $this->defaults['footer1_padding_bottom'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
            )
        );
        $wp_customize->add_control( 'footer1_padding_bottom',
            array(
                'label' => __( 'Padding Bottom', 'woddingat' ),
                'section' => 'footer_section',
                'type' => 'number',
                'active_callback' => 'rttheme_is_footer1_enabled',
            )
        );
        /**
        * Footer 2 Background
        ========================================================================================*/
        $wp_customize->add_setting('footer2_heading', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'footer2_heading', array(
            'label' => esc_html__( 'Footer 2 Background', 'woddingat' ),
            'section' => 'footer_section',
            'active_callback'   => 'rttheme_is_footer2_enabled',
        )));
        // Display Footer 2 Background Image
        $wp_customize->add_setting( 'display_footer2_bg_image',
            array(
                'default'           => $this->defaults['display_footer2_bg_image'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'display_footer2_bg_image',
            array(
                'label'           => __( 'Background Image', 'woddingat' ),
                'section'         => 'footer_section',
                'active_callback'   => 'rttheme_is_footer2_enabled',
            )
        ) );
        // Banner background image
        $wp_customize->add_setting( 'footer2_bg_img',
            array(
                'default' => $this->defaults['footer2_bg_img'],
                'transport' => 'refresh',
                'sanitize_callback' => 'absint',
            )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'footer2_bg_img',
            array(
                'label' => esc_html__( 'Background Image 1', 'woddingat' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'woddingat' ),
                'section' => 'footer_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => esc_html__( 'Select File', 'woddingat' ),
                    'change' => esc_html__( 'Change File', 'woddingat' ),
                    'default' => esc_html__( 'Default', 'woddingat' ),
                    'remove' => esc_html__( 'Remove', 'woddingat' ),
                    'placeholder' => esc_html__( 'No file selected', 'woddingat' ),
                    'frame_title' => esc_html__( 'Select File', 'woddingat' ),
                    'frame_button' => esc_html__( 'Choose File', 'woddingat' ),
                ),
                'active_callback'   => 'rttheme_is_footer2_enabled',
            )
        ) );
        $wp_customize->add_setting( 'footer2_bg_img2',
            array(
                'default' => $this->defaults['footer2_bg_img2'],
                'transport' => 'refresh',
                'sanitize_callback' => 'absint',
            )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'footer2_bg_img2',
            array(
                'label' => esc_html__( 'Background Image 2', 'woddingat' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'woddingat' ),
                'section' => 'footer_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => esc_html__( 'Select File', 'woddingat' ),
                    'change' => esc_html__( 'Change File', 'woddingat' ),
                    'default' => esc_html__( 'Default', 'woddingat' ),
                    'remove' => esc_html__( 'Remove', 'woddingat' ),
                    'placeholder' => esc_html__( 'No file selected', 'woddingat' ),
                    'frame_title' => esc_html__( 'Select File', 'woddingat' ),
                    'frame_button' => esc_html__( 'Choose File', 'woddingat' ),
                ),
                'active_callback'   => 'rttheme_is_footer2_enabled',
            )
        ) );
        // Banner background color
        $wp_customize->add_setting('footer2_bg_color', 
            array(
                'default' => $this->defaults['footer2_bg_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer2_bg_color',
            array(
                'label' => esc_html__('Background Color', 'woddingat'),
                'settings' => 'footer2_bg_color', 
                'priority' => 10, 
                'section' => 'footer_section',
                'active_callback'   => 'rttheme_is_footer2_enabled',
            )
        ));
        // Banner background color opacity
        $wp_customize->add_setting( 'footer2_bg_opacity',
            array(
                'default' => $this->defaults['footer2_bg_opacity'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
            )
        );
        $wp_customize->add_control( 'footer2_bg_opacity',
            array(
                'label' => esc_html__( 'Background Opacity', 'woddingat' ),
                'section' => 'footer_section',
                'type' => 'number',
                'active_callback'   => 'rttheme_is_footer2_enabled',
            )
        );
        // Footer 2 padding top
        $wp_customize->add_setting( 'footer2_padding_top',
            array(
                'default' => $this->defaults['footer2_padding_top'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
            )
        );
        $wp_customize->add_control( 'footer2_padding_top',
            array(
                'label' => __( 'Padding Top', 'woddingat' ),
                'section' => 'footer_section',
                'type' => 'number',
                'active_callback' => 'rttheme_is_footer2_enabled',
            )
        );
        // Footer 2 padding bottom
        $wp_customize->add_setting( 'footer2_padding_bottom',
            array(
                'default' => $this->defaults['footer2_padding_bottom'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
            )
        );
        $wp_customize->add_control( 'footer2_padding_bottom',
            array(
                'label' => __( 'Padding Bottom', 'woddingat' ),
                'section' => 'footer_section',
                'type' => 'number',
                'active_callback' => 'rttheme_is_footer2_enabled',
            )
        );
        // Display Footer Top Area
        $wp_customize->add_setting( 'display_footertop_area',
            array(
                'default'           => $this->defaults['display_footertop_area'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'display_footertop_area',
            array(
                'label'           => __( 'Display Top Area', 'woddingat' ),
                'section'         => 'footer_section',
                'active_callback'   => 'rttheme_is_footer_onetwo_enabled',
            )
        ) );
        // Display Footer Logo
        $wp_customize->add_setting( 'display_footer_logo',
            array(
                'default'           => $this->defaults['display_footer_logo'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'display_footer_logo',
            array(
                'label'           => __( 'Display Footer Logo', 'woddingat' ),
                'section'         => 'footer_section',
                'active_callback'   => 'rttheme_is_footer_onetwo_enabled',
            )
        ) );
        // Footer Logo
        $wp_customize->add_setting('footer_logo',
             array(
                 'default'           => $this->defaults['footer_logo'],
                 'transport'         => 'refresh',
                 'sanitize_callback' => 'absint',                     
             )
        );
          $wp_customize->add_control(new WP_Customize_Media_Control($wp_customize, 'footer_logo',
              array(
                  'label'         => esc_html__('Footer Logo', 'woddingat'),
                  'description'   => esc_html__('This is the description for the Media Control', 'woddingat'),
                  'section'       => 'footer_section',
                  'mime_type'     => 'image',
                  'button_labels' => array(
                      'select'       => esc_html__('Select File', 'woddingat'),
                      'change'       => esc_html__('Change File', 'woddingat'),
                      'default'      => esc_html__('Default', 'woddingat'),
                      'remove'       => esc_html__('Remove', 'woddingat'),
                      'placeholder'  => esc_html__('No file selected', 'woddingat'),
                      'frame_title'  => esc_html__('Select File', 'woddingat'),
                      'frame_button' => esc_html__('Choose File', 'woddingat'),
                  ),
              )
          ));
        // Address
        $wp_customize->add_setting( 'footer_address',
            array(
                'default'           => $this->defaults['footer_address'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'footer_address',
            array(
                'label'           => __( 'Address', 'woddingat' ),
                'section'         => 'footer_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_footertop_enabled',
            )
        );
        // Email
        $wp_customize->add_setting( 'footer_email',
            array(
                'default'           => $this->defaults['footer_email'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'footer_email',
            array(
                'label'           => __( 'Email', 'woddingat' ),
                'section'         => 'footer_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_footertop_enabled',
            )
        );
        // Email
        $wp_customize->add_setting( 'footer_phone',
            array(
                'default'           => $this->defaults['footer_phone'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'footer_phone',
            array(
                'label'           => __( 'Phone', 'woddingat' ),
                'section'         => 'footer_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_footertop_enabled',
            )
        );
        // Display Copyright Area
        $wp_customize->add_setting( 'footer_socials',
            array(
                'default'           => $this->defaults['footer_socials'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'footer_socials',
            array(
                'label'           => __( 'Display Socials', 'woddingat' ),
                'section'         => 'footer_section',
            )
        ) );
        // Display Copyright Area
        $wp_customize->add_setting( 'display_copyright_area',
            array(
                'default'           => $this->defaults['display_copyright_area'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'display_copyright_area',
            array(
                'label'           => __( 'Display Copyright Area', 'woddingat' ),
                'section'         => 'footer_section',
            )
        ) );
        // Copyright Text
        $wp_customize->add_setting( 'copyright_text',
            array(
                'default'           => $this->defaults['copyright_text'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'sanitize_textarea_field',
                'active_callback'   => 'rttheme_is_display_copyright_enabled',
            )
        );
        $wp_customize->add_control( 'copyright_text',
            array(
                'label'           => __( 'Copyright Text', 'woddingat' ),
                'section'         => 'footer_section',
                'type'            => 'textarea',
                'active_callback' => 'rttheme_is_display_copyright_enabled',
            )
        );
    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new RDTheme_Footer_Settings();
}
