<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\woddingat\Customizer\Settings;

use radiustheme\woddingat\Customizer\RDTheme_Customizer;
use radiustheme\woddingat\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\woddingat\Customizer\Controls\Customizer_Separator_Control;
use radiustheme\woddingat\Customizer\Controls\Customizer_Image_Radio_Control;
use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Header_Settings extends RDTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_header_controls' ) );
	}

    public function register_header_controls( $wp_customize ) {

        // Header Style
        $wp_customize->add_setting( 'header_style',
            array(
                'default' => $this->defaults['header_style'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );

        $wp_customize->add_control( new Customizer_Image_Radio_Control( $wp_customize, 'header_style',
            array(
                'label' => __( 'Header Layout', 'woddingat' ),
                'description' => esc_html__( 'You can override this settings only Mobile', 'woddingat' ),
                'section' => 'header_section',
                'choices' => array(
                    '1' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/header-1.png',
                        'name' => __( 'Layout 1', 'woddingat' )
                    ),                  
                    '2' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/header-2.png',
                        'name' => __( 'Layout 2', 'woddingat' )
                    ),
                    '3' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/header-3.png',
                        'name' => __( 'Layout 3', 'woddingat' )
                    ),
                    '4' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/header-4.png',
                        'name' => __( 'Layout 4', 'woddingat' )
                    ),
                    '5' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/header-5.png',
                        'name' => __( 'Layout 5', 'woddingat' )
                    ),
                )
            )
        ) );

        // Header 2 Background color
        $wp_customize->add_setting('header1_bg_color', 
            array(
                'default' => $this->defaults['header1_bg_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header1_bg_color',
            array(
                'label' => esc_html__('Background Color', 'salion'),
                'section' => 'header_section',
                'active_callback' => 'rttheme_is_header_style1_enabled',
            )
        ));

        /**
         * Separator
         */
        $wp_customize->add_setting('separator_top_bar', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Separator_Control($wp_customize, 'separator_top_bar', array(
            'settings' => 'separator_top_bar',
            'section' => 'header_section',
            'active_callback' => 'rttheme_is_header_style1_enabled',
        )));

        // Switch for Top Bar
        $wp_customize->add_setting( 'top_bar',
            array(
                'default'           => $this->defaults['top_bar'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'top_bar',
            array(
                'label'   => __( 'Top Bar', 'woddingat' ),
                'section' => 'header_section',
                'active_callback' => 'rttheme_is_header_style1_enabled',
            )
        ) );

        // Address
        $wp_customize->add_setting( 'header_address',
            array(
                'default'           => $this->defaults['header_address'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'header_address',
            array(
                'label'           => __( 'Address', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_header_top_enabled',
            )
        );

        // Phone Title
        $wp_customize->add_setting( 'header_phone_title',
            array(
                'default'           => $this->defaults['header_phone_title'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'header_phone_title',
            array(
                'label'           => __( 'Phone Title', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_header_top_enabled',
            )
        );

        // Phone
        $wp_customize->add_setting( 'header_phone',
            array(
                'default'           => $this->defaults['header_phone'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'header_phone',
            array(
                'label'           => __( 'Phone', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_header_top_enabled',
            )
        );

        // Hours Title
        $wp_customize->add_setting( 'header_hours_title',
            array(
                'default'           => $this->defaults['header_hours_title'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'header_hours_title',
            array(
                'label'           => __( 'Hours Title', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_header_top_enabled',
            )
        );

        // Hours
        $wp_customize->add_setting( 'header_hours',
            array(
                'default'           => $this->defaults['header_hours'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'header_hours',
            array(
                'label'           => __( 'Hours', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_header_top_enabled',
            )
        );

        /**
         * Separator
         */
        $wp_customize->add_setting('separator_socials', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Separator_Control($wp_customize, 'separator_socials', array(
            'settings' => 'separator_socials',
            'section' => 'header_section',
            'active_callback' => 'rttheme_is_header_style1_enabled',
        )));

        // Switch for Socials
        $wp_customize->add_setting( 'header_social',
            array(
                'default'           => $this->defaults['header_social'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'header_social',
            array(
                'label'   => __( 'Socials', 'woddingat' ),
                'section' => 'header_section',
                'active_callback' => 'rttheme_is_header_style1_enabled',
            )
        ) );

         /**
         * Separator
         */
        $wp_customize->add_setting('separator_menu_right', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Separator_Control($wp_customize, 'separator_menu_right', array(
            'settings' => 'separator_menu_right',
            'section' => 'header_section',
        )));

        // Switch for menu right part
        $wp_customize->add_setting( 'menu_right_part',
            array(
                'default' => $this->defaults['menu_right_part'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'menu_right_part',
            array(
                'label' => __( 'Menu Right', 'woddingat' ),
                'section' => 'header_section',
            )
        ) );

        // Switch for menu search icon
        $wp_customize->add_setting( 'search_icon',
            array(
                'default' => $this->defaults['search_icon'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
                'active_callback' => 'rttheme_is_menu_right_enabled',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'search_icon',
            array(
                'label' => __( 'Search Icon', 'woddingat' ),
                'section' => 'header_section',
                'active_callback' => 'rttheme_is_menu_right_enabled',
            )
        ) );

        // Switch for offcanvas menu
        $wp_customize->add_setting( 'offcanvas_menu',
            array(
                'default' => $this->defaults['offcanvas_menu'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'offcanvas_menu',
            array(
                'label' => __( 'Offcanvas Menu', 'woddingat' ),
                'section' => 'header_section',
                'active_callback' => 'rttheme_is_menu_right_enabled',
            )
        ) );

        // Offcanvas Menu Logo
        $wp_customize->add_setting('offcanvas_menu_logo',
             array(
                 'default'           => $this->defaults['offcanvas_menu_logo'],
                 'transport'         => 'refresh',
                 'sanitize_callback' => 'absint',                     
             )
        );
          $wp_customize->add_control(new WP_Customize_Media_Control($wp_customize, 'offcanvas_menu_logo',
              array(
                  'label'         => esc_html__('Offcanvas Menu Logo', 'woddingat'),
                  'description'   => esc_html__('This is the description for the Media Control', 'woddingat'),
                  'section'       => 'header_section',
                  'mime_type'     => 'image',
                  'button_labels' => array(
                      'select'       => esc_html__('Select File', 'woddingat'),
                      'change'       => esc_html__('Change File', 'woddingat'),
                      'default'      => esc_html__('Default', 'woddingat'),
                      'remove'       => esc_html__('Remove', 'woddingat'),
                      'placeholder'  => esc_html__('No file selected', 'woddingat'),
                      'frame_title'  => esc_html__('Select File', 'woddingat'),
                      'frame_button' => esc_html__('Choose File', 'woddingat'),
                  ),
                  'active_callback' => 'rttheme_is_offcanvas_menu_enabled',
              )
          ));
        // Offcanvas Menu Description
        $wp_customize->add_setting( 'offcanvm_desc',
            array(
                'default'           => $this->defaults['offcanvm_desc'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'sanitize_textarea_field',
            )
        );
        $wp_customize->add_control( 'offcanvm_desc',
            array(
                'label'           => __( 'Offcanvas Menu Description', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'textarea',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        );
        // Offcanvas Menu Title
        $wp_customize->add_setting( 'offcanvm_title',
            array(
                'default'           => $this->defaults['offcanvm_title'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_title',
            array(
                'label'           => __( 'Offcanvas Menu Title', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        );
        // Offcanvas Menu Sub Title
        $wp_customize->add_setting( 'offcanvm_sub_title',
            array(
                'default'           => $this->defaults['offcanvm_sub_title'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_sub_title',
            array(
                'label'           => __( 'Offcanvas Menu Sub Title', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        );
        // Offcanvas Menu Date
        $wp_customize->add_setting( 'offcanvm_date',
            array(
                'default'           => $this->defaults['offcanvm_date'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_date',
            array(
                'label'           => __( 'Offcanvas Menu Date', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        );
        // Offcanvas Menu Time
        $wp_customize->add_setting( 'offcanvm_time',
            array(
                'default'           => $this->defaults['offcanvm_time'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_time',
            array(
                'label'           => __( 'Offcanvas Menu Time', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        );
        // Offcanvas Menu Address 1
        $wp_customize->add_setting( 'offcanvm_address1',
            array(
                'default'           => $this->defaults['offcanvm_address1'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_address1',
            array(
                'label'           => __( 'Offcanvas Menu Address 1', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        );
        // Offcanvas Menu Address 2
        $wp_customize->add_setting( 'offcanvm_address2',
            array(
                'default'           => $this->defaults['offcanvm_address2'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_address2',
            array(
                'label'           => __( 'Offcanvas Menu Address 2', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        );
        // Offcanvas Menu Phone
        $wp_customize->add_setting( 'offcanvm_phone',
            array(
                'default'           => $this->defaults['offcanvm_phone'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_phone',
            array(
                'label'           => __( 'Offcanvas Menu Phone', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        );
        // Offcanvas Menu Map Text
        $wp_customize->add_setting( 'offcanvm_map_text',
            array(
                'default'           => $this->defaults['offcanvm_map_text'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_map_text',
            array(
                'label'           => __( 'Offcanvas Menu Map Text', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        );
        // Offcanvas Menu Map Link
        $wp_customize->add_setting( 'offcanvm_map_link',
            array(
                'default'           => $this->defaults['offcanvm_map_link'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_map_link',
            array(
                'label'           => __( 'Offcanvas Menu Map Link', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        );
        // Switch for offcanvas menu socials
        $wp_customize->add_setting( 'offcanvm_socials',
            array(
                'default' => $this->defaults['offcanvm_socials'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'offcanvm_socials',
            array(
                'label' => __( 'Offcanvas Menu Socials', 'woddingat' ),
                'section' => 'header_section',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        ) );
        // Facebook
        $wp_customize->add_setting( 'offcanvm_facebook_text',
            array(
                'default'           => $this->defaults['offcanvm_facebook_text'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_facebook_text',
            array(
                'label'           => __( 'Facebook Text', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        $wp_customize->add_setting( 'offcanvm_facebook_link',
            array(
                'default'           => $this->defaults['offcanvm_facebook_link'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_facebook_link',
            array(
                'label'           => __( 'Facebook Link', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        // Twitter
        $wp_customize->add_setting( 'offcanvm_twitter_text',
            array(
                'default'           => $this->defaults['offcanvm_twitter_text'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_twitter_text',
            array(
                'label'           => __( 'Twitter Text', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        $wp_customize->add_setting( 'offcanvm_twitter_link',
            array(
                'default'           => $this->defaults['offcanvm_twitter_link'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_twitter_link',
            array(
                'label'           => __( 'Twitter Link', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );

        // Behance
        $wp_customize->add_setting( 'offcanvm_behance_text',
            array(
                'default'           => $this->defaults['offcanvm_behance_text'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_behance_text',
            array(
                'label'           => __( 'Behance Text', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        $wp_customize->add_setting( 'offcanvm_behance_link',
            array(
                'default'           => $this->defaults['offcanvm_behance_link'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_behance_link',
            array(
                'label'           => __( 'Behance Link', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        // Pinterest
        $wp_customize->add_setting( 'offcanvm_pinterest_text',
            array(
                'default'           => $this->defaults['offcanvm_pinterest_text'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_pinterest_text',
            array(
                'label'           => __( 'Pinterest Text', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        $wp_customize->add_setting( 'offcanvm_pinterest_link',
            array(
                'default'           => $this->defaults['offcanvm_pinterest_link'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_pinterest_link',
            array(
                'label'           => __( 'Pinterest Link', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        // Google Plus
        $wp_customize->add_setting( 'offcanvm_gplus_text',
            array(
                'default'           => $this->defaults['offcanvm_gplus_text'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_gplus_text',
            array(
                'label'           => __( 'Google Plus Text', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        $wp_customize->add_setting( 'offcanvm_gplus_link',
            array(
                'default'           => $this->defaults['offcanvm_gplus_link'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_gplus_link',
            array(
                'label'           => __( 'Google Plus Link', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        // Linkedin
        $wp_customize->add_setting( 'offcanvm_linkedin_text',
            array(
                'default'           => $this->defaults['offcanvm_linkedin_text'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_linkedin_text',
            array(
                'label'           => __( 'Linkedin Text', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        $wp_customize->add_setting( 'offcanvm_linkedin_link',
            array(
                'default'           => $this->defaults['offcanvm_linkedin_link'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_linkedin_link',
            array(
                'label'           => __( 'Linkedin Link', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        // Dribbble
        $wp_customize->add_setting( 'offcanvm_dribbble_text',
            array(
                'default'           => $this->defaults['offcanvm_dribbble_text'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_dribbble_text',
            array(
                'label'           => __( 'Dribbble Text', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        $wp_customize->add_setting( 'offcanvm_dribbble_link',
            array(
                'default'           => $this->defaults['offcanvm_dribbble_link'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_dribbble_link',
            array(
                'label'           => __( 'Dribbble Link', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        // Youtube
        $wp_customize->add_setting( 'offcanvm_youtube_text',
            array(
                'default'           => $this->defaults['offcanvm_youtube_text'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_youtube_text',
            array(
                'label'           => __( 'Youtube Text', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        $wp_customize->add_setting( 'offcanvm_youtube_link',
            array(
                'default'           => $this->defaults['offcanvm_youtube_link'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_youtube_link',
            array(
                'label'           => __( 'Youtube Link', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        // Instagram
        $wp_customize->add_setting( 'offcanvm_instagram_text',
            array(
                'default'           => $this->defaults['offcanvm_instagram_text'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_instagram_text',
            array(
                'label'           => __( 'Instagram Text', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        $wp_customize->add_setting( 'offcanvm_instagram_link',
            array(
                'default'           => $this->defaults['offcanvm_instagram_link'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_instagram_link',
            array(
                'label'           => __( 'Instagram Link', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        // Skype
        $wp_customize->add_setting( 'offcanvm_skype_text',
            array(
                'default'           => $this->defaults['offcanvm_skype_text'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_skype_text',
            array(
                'label'           => __( 'Skype Text', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        $wp_customize->add_setting( 'offcanvm_skype_link',
            array(
                'default'           => $this->defaults['offcanvm_skype_link'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_skype_link',
            array(
                'label'           => __( 'Skype Link', 'woddingat' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );

    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new RDTheme_Header_Settings();
}
