<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\woddingat\Customizer\Settings;

use radiustheme\woddingat\Customizer\RDTheme_Customizer;
use radiustheme\woddingat\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\woddingat\Customizer\Controls\Customizer_Separator_Control;
use radiustheme\woddingat\Customizer\Controls\Customizer_Heading_Control;
use radiustheme\woddingat\Customizer\Controls\Customizer_Image_Radio_Control;
use radiustheme\woddingat\Customizer\Controls\Customizer_Gallery_Control;
use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Portfolio_Settings extends RDTheme_Customizer {

    public function __construct() {
        parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_portfolio_controls' ) );
    }

    /**
     * Portfolio Post Controls
     */
    public function register_portfolio_controls( $wp_customize ) {


        // Posts per page
        $wp_customize->add_setting( 'portfolio_archive_number',
            array(
                'default' => $this->defaults['portfolio_archive_number'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer'
            )
        );
        $wp_customize->add_control( 'portfolio_archive_number',
            array(
                'label' => esc_html__( 'Posts Per Page', 'woddingat' ),
                'section' => 'portfolio_section',
                'type' => 'number'
            )
        );
        $wp_customize->add_setting( 'portfolio_style',
            array(
                'default' => $this->defaults['portfolio_style'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );
        $wp_customize->add_control( new Customizer_Image_Radio_Control( $wp_customize, 'portfolio_style',
            array(
                'label' => esc_html__( 'Layout', 'woddingat' ),
                'description' => esc_html__( 'Select the portfolio layout for portfolio archive page', 'woddingat' ),
                'section' => 'portfolio_section',
                'choices' => array(
                    '1' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/three-column.jpg',
                        'name' => esc_html__( 'Three Column', 'woddingat' )
                    ),
                    '2' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/four-column.jpg',
                        'name' => esc_html__( 'Four Column', 'woddingat' )
                    ),
                )
            )
        ) );

        // Columns Width
        $wp_customize->add_setting( 'portfolio_grid_cols',
            array(
                'default' => $this->defaults['portfolio_grid_cols'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );
        $wp_customize->add_control( 'portfolio_grid_cols',
            array(
                'label' => esc_html__( 'Grid Columns', 'woddingat' ),
                'section' => 'portfolio_section',
                'description' => esc_html__( 'Width is defined by the number of bootstrap columns. Please note, portfolio columns devided by the selected bootstrap columns', 'woddingat' ),
                'type' => 'select',
                'choices' => array(
                    '6' => esc_html__( '2 Columns', 'woddingat' ),
                    '4' => esc_html__( '3 Columns', 'woddingat' ),
                    '3' => esc_html__( '4 Columns', 'woddingat' ),
                    '2' => esc_html__( '6 Columns', 'woddingat' ),
                ),
                'active_callback' => 'rttheme_portfolio_grid_enabled',
            )
        );

        // Add our Category switch setting and control for opening URLs in a new tab
        $wp_customize->add_setting( 'portfolio_category',
            array(
                'default' => $this->defaults['portfolio_category'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'portfolio_category',
            array(
                'label' => esc_html__( 'Category', 'woddingat' ),
                'section' => 'portfolio_section',
            )
        ) );


        // Portfolio Category Slug
        $wp_customize->add_setting( 'portfolio_cat_slug',
            array(
                'default' => $this->defaults['portfolio_cat_slug'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization'
            )
        );
        $wp_customize->add_control( 'portfolio_cat_slug',
            array(
                'label' => __( 'Portfolio Category Slug', 'woddingat' ),
                'section' => 'portfolio_section',
                'type' => 'text'
            )
        );

        /**
         * Heading for single Portfolio
         */
        $wp_customize->add_setting('single_portfolio_heading', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'single_portfolio_heading', array(
            'label' => esc_html__( 'Single Portfolio', 'woddingat' ),
            'section' => 'portfolio_section',
        )));

        // Single Portfolio Slug
        $wp_customize->add_setting( 'single_portfolio_slug',
            array(
                'default' => $this->defaults['single_portfolio_slug'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization'
            )
        );
        $wp_customize->add_control( 'single_portfolio_slug',
            array(
                'label' => esc_html__( 'Single Portfolio Slug', 'woddingat' ),
                'section' => 'portfolio_section',
                'type' => 'text'
            )
        );

        $wp_customize->add_setting( 'single_portfolio_layout',
            array(
                'default' => $this->defaults['single_portfolio_layout'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );
        $wp_customize->add_control( new Customizer_Image_Radio_Control( $wp_customize, 'single_portfolio_layout',
            array(
                'label' => esc_html__( 'Layout', 'woddingat' ),
                'description' => esc_html__( 'Select the layout for portfolio single page', 'woddingat' ),
                'section' => 'portfolio_section',
                'choices' => array(
                    '1' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/single_pro_cols1.jpg',
                        'name' => esc_html__( 'Layout Style 1', 'woddingat' )
                    ),
                    '2' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/single_pro_cols2.jpg',
                        'name' => esc_html__( 'Layout Style 2', 'woddingat' )
                    ),
                    '3' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/single_pro_cols3.jpg',
                        'name' => esc_html__( 'Layout Style 3', 'woddingat' )
                    ),
                )
            )
        ) );
         // single Cat
        $wp_customize->add_setting( 'portfolio_showcat',
            array(
                'default' => $this->defaults['portfolio_showcat'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'portfolio_showcat',
            array(
                'label' => esc_html__( 'Show Category', 'woddingat' ),
                'section' => 'portfolio_section',
            )
        ) );

        // Client
        $wp_customize->add_setting( 'portfolio_showclient',
            array(
                'default' => $this->defaults['portfolio_showclient'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'portfolio_showclient',
            array(
                'label' => esc_html__( 'Show Client', 'woddingat' ),
                'section' => 'portfolio_section',
            )
        ) );
        // Date
        $wp_customize->add_setting( 'portfolio_showdate',
            array(
                'default' => $this->defaults['portfolio_showdate'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'portfolio_showdate',
            array(
                'label' => esc_html__( 'Show Date', 'woddingat' ),
                'section' => 'portfolio_section',
            )
        ) );
        // Share
        $wp_customize->add_setting( 'portfolio_showshare',
            array(
                'default' => $this->defaults['portfolio_showshare'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'portfolio_showshare',
            array(
                'label' => esc_html__( 'Show Share', 'woddingat' ),
                'section' => 'portfolio_section',
            )
        ) );
        // Nav
        $wp_customize->add_setting( 'portfolio_prevnext',
            array(
                'default' => $this->defaults['portfolio_prevnext'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'portfolio_prevnext',
            array(
                'label' => esc_html__( 'Prev/Nex', 'woddingat' ),
                'section' => 'portfolio_section',
            )
        ) );
        /**
         * Banner Separator
         */
        $wp_customize->add_setting('separator_portfolio_page_banner', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Separator_Control($wp_customize, 'separator_portfolio_page_banner', array(
            'settings' => 'separator_portfolio_page_banner',
            'section' => 'portfolio_section',
        )));

        $wp_customize->add_setting( 'portfolio_banner',
            array(
                'default' => $this->defaults['portfolio_banner'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'portfolio_banner',
            array(
                'label' => __( 'Banner', 'woddingat' ),
                'section' => 'portfolio_section',
            )
        ) );

        // Banner BG Type 
        $wp_customize->add_setting( 'portfolio_banner_bg_type',
            array(
                'default' => $this->defaults['portfolio_banner_bg_type'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
                'active_callback' => 'rttheme_is_portfolio_banner_enabled',
            )
        );
        $wp_customize->add_control( 'portfolio_banner_bg_type',
            array(
                'label' => __( 'Banner Background Type', 'woddingat' ),
                'section' => 'portfolio_section',
                'description' => esc_html__( 'This is banner background type.', 'woddingat' ),
                'type' => 'select',
                'choices' => array(
                    'bgimg' => esc_html__( 'BG Image', 'woddingat' ),
                    'bgcolor' => esc_html__( 'BG Color', 'woddingat' ),
                ),
                'active_callback' => 'rttheme_is_portfolio_banner_enabled',
            )
        );

        $wp_customize->add_setting( 'portfolio_banner_bgimg',
            array(
                'default' => $this->defaults['portfolio_banner_bgimg'],
                'transport' => 'refresh',
                'sanitize_callback' => 'absint',
                'active_callback' => 'rttheme_portfolio_banner_bgimg_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'portfolio_banner_bgimg',
            array(
                'label' => __( 'Banner Background Image', 'woddingat' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'woddingat' ),
                'section' => 'portfolio_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => __( 'Select File', 'woddingat' ),
                    'change' => __( 'Change File', 'woddingat' ),
                    'default' => __( 'Default', 'woddingat' ),
                    'remove' => __( 'Remove', 'woddingat' ),
                    'placeholder' => __( 'No file selected', 'woddingat' ),
                    'frame_title' => __( 'Select File', 'woddingat' ),
                    'frame_button' => __( 'Choose File', 'woddingat' ),
                ),
                'active_callback' => 'rttheme_portfolio_banner_bgimg_type_condition',
            )
        ) );
        // Banner background image overlay
        $wp_customize->add_setting('portfolio_banner_bgimage_overlay', 
            array(
                'default' => 'rgba(0, 0, 0, 0.5)', 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_portfolio_banner_bgimg_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'portfolio_banner_bgimage_overlay',
            array(
                'label' => esc_html__('Banner Background Overlay Color', 'woddingat'),
                'settings' => 'portfolio_banner_bgimage_overlay', 
                'priority' => 10, 
                'section' => 'portfolio_section', 
                'active_callback' => 'rttheme_portfolio_banner_bgimg_type_condition',
            )
        ));
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'portfolio_banner_bgimage_overlay',
            array(
                'label' => esc_html__('Banner Background Overlay Color', 'woddingat'),
                'settings' => 'portfolio_banner_bgimage_overlay', 
                'priority' => 10, 
                'section' => 'portfolio_section', 
                'active_callback' => 'rttheme_portfolio_banner_bgimg_type_condition',
            )
        ));
        // Banner background color opacity
        $wp_customize->add_setting( 'portfolio_overlay_opacity',
            array(
                'default' => $this->defaults['portfolio_overlay_opacity'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
                'active_callback' => 'rttheme_portfolio_banner_bgimg_type_condition',
            )
        );
        $wp_customize->add_control( 'portfolio_overlay_opacity',
            array(
                'label' => __( 'Overlay Opacity', 'woddingat' ),
                'section' => 'portfolio_section',
                'type' => 'number',
                'active_callback' => 'rttheme_portfolio_banner_bgimg_type_condition',
            )
        );

        // Banner background color
        $wp_customize->add_setting('portfolio_banner_bgcolor', 
            array(
                'default' => 'rgba(19, 21, 32, 1)', 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_portfolio_banner_bgcolor_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'portfolio_banner_bgcolor',
            array(
                'label' => esc_html__('Banner Background Color', 'woddingat'),
                'settings' => 'portfolio_banner_bgcolor', 
                'priority' => 10, 
                'section' => 'portfolio_section', 
                'active_callback' => 'rttheme_portfolio_banner_bgcolor_type_condition',
            )
        ));

        /**
         * Separator
         */
        $wp_customize->add_setting('separator_portfolio_page_breadcrumb', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Separator_Control($wp_customize, 'separator_portfolio_page_breadcrumb', array(
            'settings' => 'separator_portfolio_page_breadcrumb',
            'section' => 'portfolio_section',
        )));

        $wp_customize->add_setting( 'portfolio_breadcrumb',
            array(
                'default' => $this->defaults['portfolio_breadcrumb'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'portfolio_breadcrumb',
            array(
                'label' => __( 'Breadcrumb', 'woddingat' ),
                'section' => 'portfolio_section',
            )
        ) );

        // Banner padding top
        $wp_customize->add_setting( 'portfolio_inner_padding_top',
            array(
                'default' => $this->defaults['portfolio_inner_padding_top'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
                'active_callback' => 'rttheme_is_single_portfolio_banner_enabled',
            )
        );
        $wp_customize->add_control( 'portfolio_inner_padding_top',
            array(
                'label' => __( 'Banner Padding Top', 'woddingat' ),
                'section' => 'portfolio_section',
                'type' => 'number',
                'active_callback' => 'rttheme_is_single_portfolio_banner_enabled',
            )
        );
        // Banner padding bottom
        $wp_customize->add_setting( 'portfolio_inner_padding_bottom',
            array(
                'default' => $this->defaults['portfolio_inner_padding_bottom'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
                'active_callback' => 'rttheme_is_single_portfolio_banner_enabled',
            )
        );
        $wp_customize->add_control( 'portfolio_inner_padding_bottom',
            array(
                'label' => __( 'Banner Padding Bottom', 'woddingat' ),
                'section' => 'portfolio_section',
                'type' => 'number',
                'active_callback' => 'rttheme_is_single_portfolio_banner_enabled',
            )
        );

    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
    new RDTheme_Portfolio_Settings();
}
