<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\woddingat\Customizer\Settings;

use radiustheme\woddingat\Customizer\RDTheme_Customizer;
use radiustheme\woddingat\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\woddingat\Customizer\Controls\Customizer_Separator_Control;
use radiustheme\woddingat\Customizer\Controls\Customizer_Heading_Control;
use radiustheme\woddingat\Customizer\Controls\Customizer_Image_Radio_Control;
use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Services_Archive_Settings extends RDTheme_Customizer {

    public function __construct() {
        parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_services_archive_controls' ) );
    }

    /**
     * Case Post Controls
     */
    public function register_services_archive_controls( $wp_customize ) {

         // Excerpt Length
        $wp_customize->add_setting( 'service_archive_excerpt_length',
            array(
                'default' => $this->defaults['service_archive_excerpt_length'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
            )
        );
        $wp_customize->add_control( 'service_archive_excerpt_length',
            array(
                'label' => __( 'Excerpt Length', 'woddingat' ),
                'section' => 'services_section',
                'type' => 'number',
            )
        );

        // Service Category Slug
        $wp_customize->add_setting( 'service_cat_slug',
            array(
                'default' => $this->defaults['service_cat_slug'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization'
            )
        );
        $wp_customize->add_control( 'service_cat_slug',
            array(
                'label' => __( 'Service Category Slug', 'woddingat' ),
                'section' => 'services_section',
                'type' => 'text'
            )
        );

        /**
         * Heading for single Service
         */
        $wp_customize->add_setting('single_service_heading', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'single_service_heading', array(
            'label' => esc_html__( 'Single Service', 'woddingat' ),
            'section' => 'services_section',
        )));

        // Service Page Banner
        $wp_customize->add_setting( 'service_banner',
            array(
                'default' => $this->defaults['service_banner'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'service_banner',
            array(
                'label' => __( 'Banner', 'woddingat' ),
                'section' => 'services_section',
            )
        ) );

        // Banner BG Type 
        $wp_customize->add_setting( 'service_banner_bg_type',
            array(
                'default' => $this->defaults['service_banner_bg_type'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
                'active_callback' => 'rttheme_is_service_banner_enabled',
            )
        );
        $wp_customize->add_control( 'service_banner_bg_type',
            array(
                'label' => __( 'Banner Background Type', 'woddingat' ),
                'section' => 'services_section',
                'description' => esc_html__( 'This is banner background type.', 'woddingat' ),
                'type' => 'select',
                'choices' => array(
                    'bgimg' => esc_html__( 'BG Image', 'woddingat' ),
                    'bgcolor' => esc_html__( 'BG Color', 'woddingat' ),
                ),
                'active_callback' => 'rttheme_is_service_banner_enabled',
            )
        );

        $wp_customize->add_setting( 'service_banner_bgimg',
            array(
                'default' => $this->defaults['service_banner_bgimg'],
                'transport' => 'refresh',
                'sanitize_callback' => 'absint',
                'active_callback' => 'rttheme_service_banner_bgimg_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'service_banner_bgimg',
            array(
                'label' => __( 'Banner Background Image', 'woddingat' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'woddingat' ),
                'section' => 'services_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => __( 'Select File', 'woddingat' ),
                    'change' => __( 'Change File', 'woddingat' ),
                    'default' => __( 'Default', 'woddingat' ),
                    'remove' => __( 'Remove', 'woddingat' ),
                    'placeholder' => __( 'No file selected', 'woddingat' ),
                    'frame_title' => __( 'Select File', 'woddingat' ),
                    'frame_button' => __( 'Choose File', 'woddingat' ),
                ),
                'active_callback' => 'rttheme_service_banner_bgimg_type_condition',
            )
        ) );
        // Banner background image overlay
        $wp_customize->add_setting('service_banner_bgimage_overlay', 
            array(
                'default' => 'rgba(0, 0, 0, 0.5)', 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_service_banner_bgimg_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'service_banner_bgimage_overlay',
            array(
                'label' => esc_html__('Banner Background Overlay Color', 'woddingat'),
                'settings' => 'service_banner_bgimage_overlay', 
                'priority' => 10, 
                'section' => 'services_section', 
                'active_callback' => 'rttheme_service_banner_bgimg_type_condition',
            )
        ));
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'service_banner_bgimage_overlay',
            array(
                'label' => esc_html__('Banner Background Overlay Color', 'woddingat'),
                'settings' => 'service_banner_bgimage_overlay', 
                'priority' => 10, 
                'section' => 'services_section', 
                'active_callback' => 'rttheme_service_banner_bgimg_type_condition',
            )
        ));
        // Banner background color opacity
        $wp_customize->add_setting( 'service_overlay_opacity',
            array(
                'default' => $this->defaults['service_overlay_opacity'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
                'active_callback' => 'rttheme_service_banner_bgimg_type_condition',
            )
        );
        $wp_customize->add_control( 'service_overlay_opacity',
            array(
                'label' => __( 'Overlay Opacity', 'woddingat' ),
                'section' => 'services_section',
                'type' => 'number',
                'active_callback' => 'rttheme_service_banner_bgimg_type_condition',
            )
        );

        // Banner background color
        $wp_customize->add_setting('service_banner_bgcolor', 
            array(
                'default' => 'rgba(19, 21, 32, 1)', 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_service_banner_bgcolor_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'service_banner_bgcolor',
            array(
                'label' => esc_html__('Banner Background Color', 'woddingat'),
                'settings' => 'service_banner_bgcolor', 
                'priority' => 10, 
                'section' => 'services_section', 
                'active_callback' => 'rttheme_service_banner_bgcolor_type_condition',
            )
        ));

        /**
         * Separator
         */
        $wp_customize->add_setting('separator_service_page_breadcrumb', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Separator_Control($wp_customize, 'separator_service_page_breadcrumb', array(
            'settings' => 'separator_service_page_breadcrumb',
            'section' => 'services_section',
        )));

        $wp_customize->add_setting( 'service_breadcrumb',
            array(
                'default' => $this->defaults['service_breadcrumb'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'service_breadcrumb',
            array(
                'label' => __( 'Breadcrumb', 'woddingat' ),
                'section' => 'services_section',
            )
        ) );

        // Single service Slug
        $wp_customize->add_setting( 'single_service_slug',
            array(
                'default' => $this->defaults['single_service_slug'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization'
            )
        );
        $wp_customize->add_control( 'single_service_slug',
            array(
                'label' => __( 'Single Service Slug', 'woddingat' ),
                'section' => 'services_section',
                'type' => 'text'
            )
        );


        // Banner padding top
        $wp_customize->add_setting( 'service_inner_padding_top',
            array(
                'default' => $this->defaults['service_inner_padding_top'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
                'active_callback' => 'rttheme_is_single_service_banner_enabled',
            )
        );
        $wp_customize->add_control( 'service_inner_padding_top',
            array(
                'label' => __( 'Banner Padding Top', 'woddingat' ),
                'section' => 'services_section',
                'type' => 'number',
                'active_callback' => 'rttheme_is_single_service_banner_enabled',
            )
        );
        // Banner padding bottom
        $wp_customize->add_setting( 'service_inner_padding_bottom',
            array(
                'default' => $this->defaults['service_inner_padding_bottom'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
                'active_callback' => 'rttheme_is_single_service_banner_enabled',
            )
        );
        $wp_customize->add_control( 'service_inner_padding_bottom',
            array(
                'label' => __( 'Banner Padding Bottom', 'woddingat' ),
                'section' => 'services_section',
                'type' => 'number',
                'active_callback' => 'rttheme_is_single_service_banner_enabled',
            )
        );

        /**
         * Separator
         */
        $wp_customize->add_setting('separator_service_page_banner', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Separator_Control($wp_customize, 'separator_service_page_banner', array(
            'settings' => 'separator_service_page_banner',
            'section' => 'services_section',
        )));

    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
    new RDTheme_Services_Archive_Settings();
}
