<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\woddingat\Customizer\Settings;

use radiustheme\woddingat\Customizer\RDTheme_Customizer;
use radiustheme\woddingat\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\woddingat\Customizer\Controls\Customizer_Heading_Control2;
use radiustheme\woddingat\Customizer\Controls\Customizer_Image_Radio_Control;
use radiustheme\woddingat\Customizer\Controls\Customize_Control_Checkbox_Multiple;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Blog_Single_Post_Settings extends RDTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_blog_single_post_controls' ) );
	}

    /**
     * Blog Post Controls
     */
    public function register_blog_single_post_controls( $wp_customize ) {

        // Post Date
        $wp_customize->add_setting( 'post_date',
            array(
                'default' => $this->defaults['post_date'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'post_date',
            array(
                'label' => __( 'Display Date', 'woddingat' ),
                'section' => 'single_post_secttings_section',
            )
        ));

        // Post Comments
        $wp_customize->add_setting( 'post_comments',
            array(
                'default' => $this->defaults['post_comments'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'post_comments',
            array(
                'label' => __( 'Display Comments', 'woddingat' ),
                'section' => 'single_post_secttings_section',
            )
        ));
        // Post Category
        $wp_customize->add_setting( 'post_cats',
            array(
                'default' => $this->defaults['post_cats'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'post_cats',
            array(
                'label' => __( 'Display Category', 'woddingat' ),
                'section' => 'single_post_secttings_section',
            )
        ) );
        // Post Tag
        $wp_customize->add_setting( 'post_tags',
            array(
                'default' => $this->defaults['post_tags'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'post_tags',
            array(
                'label' => __( 'Display Tags', 'woddingat' ),
                'section' => 'single_post_secttings_section',
            )
        ) );
        // Author Bio
        $wp_customize->add_setting( 'show_sin_author_bio',
            array(
                'default' => $this->defaults['show_sin_author_bio'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'show_sin_author_bio',
            array(
                'label' => __( 'Display Author Bio', 'woddingat' ),
                'section' => 'single_post_secttings_section',
            )
        ) );
        // Author Sub Title
        $wp_customize->add_setting( 'sin_author_sub_title',
            array(
                'default'           => $this->defaults['sin_author_sub_title'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'sin_author_sub_title',
            array(
                'label'           => __( 'Author Sub Title', 'woddingat' ),
                'section'         => 'single_post_secttings_section',
                'type'            => 'text',
            )
        );
        /**
         * Post Share Heading
         */
        $wp_customize->add_setting('post_share_heading', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control2($wp_customize, 'post_share_heading', array(
            'label' => __( 'Post Share', 'woddingat' ),
            'section' => 'single_post_secttings_section',
        )));
        // Post Share
         $wp_customize->add_setting( 'post_share',
            array(
                'default' => $this->defaults['post_share'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'post_share',
            array(
                'label' => __( 'Post Share', 'woddingat' ),
                'section' => 'single_post_secttings_section',
            )
        ));
        // Facebook
        $wp_customize->add_setting( 'post_share_facebook',
            array(
                'default' => $this->defaults['post_share_facebook'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'post_share_facebook',
            array(
                'label' => __( 'Show Facebook', 'woddingat' ),
                'section' => 'single_post_secttings_section',
                'active_callback' => 'rttheme_is_post_social_share_enabled',
            )
        ));
        // Twitter
        $wp_customize->add_setting( 'post_share_twitter',
            array(
                'default' => $this->defaults['post_share_twitter'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'post_share_twitter',
            array(
                'label' => __( 'Show Twitter', 'woddingat' ),
                'section' => 'single_post_secttings_section',
                'active_callback' => 'rttheme_is_post_social_share_enabled',
            )
        ));
        // Linkedin
        $wp_customize->add_setting( 'post_share_linkedin',
            array(
                'default' => $this->defaults['post_share_linkedin'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'post_share_linkedin',
            array(
                'label' => __( 'Show Linkedin', 'woddingat' ),
                'section' => 'single_post_secttings_section',
                'active_callback' => 'rttheme_is_post_social_share_enabled',
            )
        ));
        // Pinterest
        $wp_customize->add_setting( 'post_share_pinterest',
            array(
                'default' => $this->defaults['post_share_pinterest'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'post_share_pinterest',
            array(
                'label' => __( 'Show Pinterest', 'woddingat' ),
                'section' => 'single_post_secttings_section',
                'active_callback' => 'rttheme_is_post_social_share_enabled',
            )
        ));
        // Tumblr
        $wp_customize->add_setting( 'post_share_tumblr',
            array(
                'default' => $this->defaults['post_share_tumblr'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'post_share_tumblr',
            array(
                'label' => __( 'Show Tumblr', 'woddingat' ),
                'section' => 'single_post_secttings_section',
                'active_callback' => 'rttheme_is_post_social_share_enabled',
            )
        ));
        // Reddit
        $wp_customize->add_setting( 'post_share_reddit',
            array(
                'default' => $this->defaults['post_share_reddit'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'post_share_reddit',
            array(
                'label' => __( 'Show Reddit', 'woddingat' ),
                'section' => 'single_post_secttings_section',
                'active_callback' => 'rttheme_is_post_social_share_enabled',
            )
        ));
        // Post Navigation
        $wp_customize->add_setting( 'post_navigation',
            array(
                'default' => $this->defaults['post_navigation'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'post_navigation',
            array(
                'label' => __( 'Display Post Navigation', 'woddingat' ),
                'section' => 'single_post_secttings_section',
            )
        ) );
    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new RDTheme_Blog_Single_Post_Settings();
}
