<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\woddingat;
use radiustheme\woddingat\inc\RDTheme;
use radiustheme\woddingat\inc\Helper;

class General_Setup {

	public function __construct() {
		add_action( 'after_setup_theme',                       array( $this, 'theme_setup' ) );	
		add_action( 'widgets_init',                            array( $this, 'register_sidebars' ) );		
		add_filter( 'body_class',                              array( $this, 'body_classes' ) );
		add_filter( 'post_class',                              array( $this, 'post_classes' ) );
		add_action( 'wp_head',                                 array( $this, 'noscript_hide_preloader' ), 1 );
		add_filter( 'get_search_form',                         array( $this, 'search_form' ) );
		add_filter( 'comment_form_fields',                     array( $this, 'move_textarea_to_bottom' ) );
		add_filter( 'excerpt_more',                            array( $this, 'excerpt_more' ) );
		add_filter( 'wp_kses_allowed_html', 	               array( $this, 'woddingat_kses_allowed_html' ), 10, 2 );		
		add_filter( 'elementor/widgets/wordpress/widget_args', array( $this, 'elementor_widget_args' ) );
		add_action( 'wp_head',                                 array( $this, 'woddingat_pingback_header' ), 996 );
		add_action( 'wp_head',                                 array( $this, 'woddingat_siteicon_header' ), 997 );
		add_action( 'wp_admin',                                array( $this, 'woddingat_siteicon_header' ), 998 );
		add_action( 'site_prealoader',                         array( $this, 'woddingat_preloader' ) );
		add_filter( 'wpcf7_autop_or_not',  					   '__return_false' ); // cf7 wptop
		add_filter( 'register_post_type_args',                 array( $this, 'update_woddingat_custom_post_slug' ), 10, 2 );
		add_filter( 'register_taxonomy_args',                  array( $this, 'woddingat_change_taxonomies_slug'), 10, 2 );
		add_action( 'template_redirect',                       array( $this, 'w3c_validator' ) );
	}

	/**
	* Add a pingback url auto-discovery header for single posts, pages, or attachments.
	*/
	public function woddingat_pingback_header() {
		if ( is_singular() && pings_open() ) {
			printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
		}
	}
	/**
	* If empty site icon then the fallback
	*/
	public function woddingat_siteicon_header() {
		if ( ! ( function_exists( 'has_site_icon' ) ) ) {
			echo '<link rel="shortcut icon">';
		}
	}	

	public function theme_setup() {
		$woddingat = WODDINGAT_THEME_PREFIX;
		// Theme supports
		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'wp-block' );
		add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption' ) );
		add_theme_support( 'post-formats', array( 'aside', 'gallery', 'video', 'audio', 'quote', 'link' ) );
		add_editor_style();
		add_theme_support( 'admin-bar', array( 'callback' => '__return_false' ) );
		remove_theme_support( 'widgets-block-editor' );
		// for gutenberg support
		add_theme_support( 'align-wide' );
		add_theme_support( 'editor-color-palette', array(
			array(
				'name'  => esc_html__( 'Primary', 'woddingat' ),
				'slug'  => 'woddingat-primary',
				'color' => '#f05f75',
			),
			array(
				'name'  => esc_html__('Secondary', 'woddingat' ),
				'slug'  => 'woddingat-secondary',
				'color' => '#fbf1f2',
			),
			array(
				'name'  => esc_html__('Light', 'woddingat' ),
				'slug'  => 'woddingat-light',
				'color' => '#ffffff',
			),
			array(
				'name'  => esc_html__('Black', 'woddingat' ),
				'slug'  => 'woddingat-black',
				'color'  => '#000000',
			),
			array(
				'name'  => esc_html__('Dark', 'woddingat' ),
				'slug'  => 'woddingat-dark',
				'color'  => '#7a7a7a',
			),
			
		) );
		add_theme_support( 'editor-font-sizes', array(
			array(
				'name' => esc_html__('Small', 'woddingat' ),
				'size'  => 12,
				'slug'  => 'small'
			),
			array(
				'name'  => esc_html__('Normal', 'woddingat' ),
				'size'  => 26,
				'slug'  => 'normal'
			),
			array(
				'name'  => esc_html__('Large', 'woddingat' ),
				'size'  => 36,
				'slug'  => 'large'
			),
			array(
				'name'  => esc_html__('Huge', 'woddingat' ),
				'size'  => 60,
				'slug'  => 'huge'
			)
		) );

		add_theme_support( 'wp-block-styles' );
		add_theme_support( 'responsive-embeds' );
		add_theme_support( 'editor-styles');		
	
		// Image sizes
		add_image_size( "woddingat-thumb-size-1", 100, 91, true ); // Blog list sidebar post thumb
		add_image_size( "woddingat-thumb-size-2", 750, 532, true ); // Blog post thumb
		add_image_size( "woddingat-thumb-size-3", 750, 1014, true ); // Masonry portfolio thumb 1
		add_image_size( "woddingat-thumb-size-4", 770, 270, true ); // Masonry portfolio thumb 2
		add_image_size( "woddingat-thumb-size-5", 750, 870, true ); // Masonry portfolio thumb 3
		add_image_size( "woddingat-thumb-size-6", 670, 745, true ); // Masonry portfolio thumb home 2
		add_image_size( "woddingat-thumb-size-7", 530, 515, true ); // Portfolio thumb siz7
		add_image_size( "woddingat-thumb-size-8", 720, 1260,true ); // Portfolio thumb siz8
	
		// Register menus
		register_nav_menus( array(
			'primary'  => esc_html__( 'Primary', 'woddingat' ),
			'offcanvas' => esc_html__( 'Offcanvas Menu', 'woddingat' ),
		) );

		// Custom Logo
		add_theme_support( 'custom-logo', array(
			'height'      => 65,
			'width'       => 245,
			'flex-height' => true,
			'header-text' => array( 'site-title', 'site-description' ),
		) );
	}


	public function register_sidebars() {
		$footer_widget_titles = array(
			'1' => esc_html__( 'Footer 1 Widget 1', 'woddingat' ),
			'2' => esc_html__( 'Footer 1 Widget 2', 'woddingat' ),
			'3' => esc_html__( 'Footer 1 Widget 3', 'woddingat' ),
			'4' => esc_html__( 'Footer 1 Widget 4', 'woddingat' ),
			'6' => esc_html__( 'Footer 1 Widget 6', 'woddingat' ),
		);
		register_sidebar( array(
			'name'          => esc_html__( 'Sidebar Widgets', 'woddingat' ),
			'id'            => 'sidebar',
			'description'   => esc_html__('Sidebar Widgets area', 'woddingat'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="widget-section-heading heading-dark"><h3 class="widget-title">',
			'after_title'   => '</h3></div>',
		) );

		for ( $i = 1; $i <= 3; $i++ ) {
			if (isset($footer_widget_titles[$i])) {
				register_sidebar( array(
					'name'          => $footer_widget_titles[$i],
					'id'            => 'footer-widgets-'. $i,
					'description'   => esc_html__('Footer widgets area', 'woddingat'),
					'before_widget' => '<div id="%1$s" class="widget %2$s footer-widgets">',
					'after_widget'  => '</div>',
					'before_title'  => '<h3 class="widget-heading">',
					'after_title'   => '</h3>',
				) );
			}
		}

	}

	public function body_classes( $classes ) {
		if ( RDTheme::$options['sticky_header'] == 1 ) {	
			$classes[] = 'sticky-header';
		}

		if (RDTheme::$tr_header === 0 || RDTheme::$tr_header == "off" ) {	
			$classes[] = 'transparent-header-disable';
		}
		
		if( is_home() || is_page() || is_archive() || is_search() || is_404() ) {
			if ( RDTheme::$has_banner != 1 ) {	
				$classes[] = 'page-banner-disable';
			}
		}
		if (is_single()) {
			if (RDTheme::$options['single_post_banner'] != 1 ) {	
				$classes[] = 'single-page-banner-disable';
			}
		}

		if ( RDTheme::$header_style == 3 ) {	
			$classes[] = 'pagepiling';
		}

		$classes[] = 'header-style-'. RDTheme::$header_style;
		
        // Sidebar
		$classes[] = ( RDTheme::$layout == 'full-width' ) ? 'no-sidebar' : 'has-sidebar';

		return $classes;
	}


	public function post_classes( $classes ) {
		$post_thumb = '';
		if ( has_post_thumbnail() ){
		    $classes[] = 'have-post-thumb';
		}
		return $classes;
	}

	public function noscript_hide_preloader(){
		// Hide preloader if js is disabled
		echo '<noscript><style>#preloader{display:none;}</style></noscript>';
	}

	public function scroll_to_top_html(){
		// Back-to-top link
		if ( RDTheme::$options['back_to_top'] ){	
		echo '<a href="#wrapper" data-type="section-switch" class="scrollup back-top">
			<i class="fas fa-angle-double-up"></i>
		</a>';
		}
	}

	public function search_form(){
		$output = '
		<form role="search" method="get" class="search-form" action="' . esc_url( home_url( '/' ) ) . '">
			<div class="widget-search">
				<div class="input-group stylish-input-group">		   
			    	<input type="text" class="form-control" placeholder="' . esc_attr__( 'Search', 'woddingat' ) . '" value="' . get_search_query() . '" name="s" />
			    	<span class="input-group-addon">
				        <button type="submit">
				            <i class="flaticon-search"></i>
				        </button>
			        </span>
				</div>
			</div>
		</form>
		';
		return $output;
	}

	public function woddingat_preloader() {
        echo '<div id="preloader"></div>';
	}

	public function move_textarea_to_bottom( $fields ) {
		$temp = $fields['comment'];
		unset( $fields['comment'] );
		$fields['comment'] = $temp;
		return $fields;
	}

	/*Allow HTML for the kses post*/
	public function woddingat_kses_allowed_html($tags, $context) {
		switch($context) {
			case 'social':
				$tags = array(
					'a' => array('href' => array()),
					'b' => array()
				);
			return $tags;
			case 'allow_link':
				$tags = array(
					'a' => array(
						'class' => array(),
						'href'  => array(),
						'rel'   => array(),
						'title' => array(),
						'target' => array(),
					),
					'b' => array()
				);
			return $tags;
			case 'alltext_allow':
				$tags = array(
					'a' => array(
						'class' => array(),
						'href'  => array(),
						'rel'   => array(),
						'title' => array(),
						'target' => array(),
					),
					'abbr' => array(
						'title' => array(),
					),
					'b' => array(),
					'br' => array(),
					'blockquote' => array(
						'cite'  => array(),
					),
					'cite' => array(
						'title' => array(),
					),
					'code' => array(),
					'del' => array(
						'datetime' => array(),
						'title' => array(),
					),
					'dd' => array(),
					'div' => array(
						'class' => array(),
						'title' => array(),
						'style' => array(),
						'id' 	=> array(),
					),
					'dl' => array(),
					'dt' => array(),
					'em' => array(),
					'h1' => array(),
					'h2' => array(),
					'h3' => array(),
					'h4' => array(),
					'h5' => array(),
					'h6' => array(),
					'i' => array(),
					'img' => array(
						'alt'    => array(),
						'class'  => array(),
						'height' => array(),
						'src'    => array(),
						'srcset' => array(),
						'width'  => array(),
					),
					'li' => array(
						'class' => array(),
					),
					'ol' => array(
						'class' => array(),
					),
					'p' => array(
						'class' => array(),
					),
					'q' => array(
						'cite' => array(),
						'title' => array(),
					),
					'span' => array(
						'class' => array(),
						'title' => array(),
						'style' => array(),
					),
					'strike' => array(),
					'strong' => array(),
					'ul' => array(
						'class' => array(),
					),
				);
				return $tags;
			default:
			return $tags;
		}
	}

	public function excerpt_more() {
		return esc_html__( '...', 'woddingat' ) ;
	}
	
	public function elementor_widget_args( $args ) {
		$args['before_widget'] = '<div class="widget single-sidebar padding-bottom1">';
		$args['after_widget']  = '</div>';
		$args['before_title']  = '<h3>';
		$args['after_title']   = '</h3>';
		return $args;
	}

	function cc_mime_types( $mimes ) {
		$mimes['svg'] = 'image/svg+xml';
		return $mimes;
	}

	/* - Woddingat Post and taxonomy slug change
	--------------------------------------------------------*/
	public function update_woddingat_custom_post_slug( $args, $post_type ) {
		$prefix = WODDINGAT_THEME_PREFIX;
		$theme = wp_get_theme(); // gets the current theme
		if ( 'Woddingat' == $theme->name || 'Woddingat' == $theme->parent_theme ) {
			$portfolio_slug = RDTheme::$options['single_portfolio_slug'];
			$service_slug = RDTheme::$options['single_service_slug'];
			$team_slug = RDTheme::$options['single_team_slug'];
		    if ( $prefix.'_portfolio' === $post_type ) {
		        $portfolio = array(
		            'rewrite' => array( 'slug' => $portfolio_slug, 'with_front' => false )
		        );
		        return array_merge( $args, $portfolio );
		    }
		    if ( $prefix.'_service' === $post_type ) {
		        $service = array(
		            'rewrite' => array( 'slug' => $service_slug, 'with_front' => false )
		        );
		        return array_merge( $args, $service );
		    }
		    if ( $prefix.'_team' === $post_type ) {
		        $team = array(
		            'rewrite' => array( 'slug' => $team_slug, 'with_front' => false )
		        );
		        return array_merge( $args, $team );
		    }
		}
		return $args;
	}

	public function woddingat_change_taxonomies_slug( $args, $taxonomy ) {
		$prefix = WODDINGAT_THEME_PREFIX;

		$portfolio_cat_slug = RDTheme::$options['portfolio_cat_slug'];
		$service_cat_slug   = RDTheme::$options['service_cat_slug'];

	    if ( $prefix.'_portfolio_category' === $taxonomy ) {
	    	$args['rewrite']['slug'] = $portfolio_cat_slug;
	    }
	    if ( $prefix.'_service_category' === $taxonomy ) {
	    	$args['rewrite']['slug'] = $service_cat_slug;
	    }
	   return $args;
	}

	public function w3c_validator() {
		/*----------------------------------------------------------------------------------------------------*/
		/*  W3C validator passing code
		/*----------------------------------------------------------------------------------------------------*/
	    ob_start( function( $buffer ){
	        $buffer = str_replace( array( '<script type="text/javascript">', "<script type='text/javascript'>" ), '<script>', $buffer );
	        return $buffer;
	    });
	    ob_start( function( $buffer2 ){
	        $buffer2 = str_replace( array( "<script type='text/javascript' src" ), '<script src', $buffer2 );
	        return $buffer2;
	    });
	    ob_start( function( $buffer3 ){
	        $buffer3 = str_replace( array( 'type="text/css"', "type='text/css'", 'type="text/css"', ), '', $buffer3 );
	        return $buffer3;
	    });
	    ob_start( function( $buffer4 ){
	        $buffer4 = str_replace( array( '<iframe frameborder="0" scrolling="no" marginheight="0" marginwidth="0"', ), '<iframe', $buffer4 );
	        return $buffer4;
	    });
		ob_start( function( $buffer5 ){
	        $buffer5 = str_replace( array( 'aria-required="true"', ), '', $buffer5 );
	        return $buffer5;
	    });
	}

}
new General_Setup;

