<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\woddingat;
use radiustheme\woddingat\inc\RDTheme;
use \WP_Query;

if( ! function_exists( 'woddingat_related_portfolio' )){
	
	function woddingat_related_portfolio(){
		$post_id = get_the_id();	
		$number_of_avail_post = '';
		$current_post = array( $post_id );

		$related_port_number = RDTheme::$options['related_port_number'];
		
		$content 	= get_the_content();
		$content 	= apply_filters( 'the_content', $content );
		
		# Making ready to the Query ...
		$query_type = RDTheme::$options['related_post_query'];

		$args = array(
			'post_type'				 => 'woddingat_portfolio',
			'post__not_in'           => $current_post,
			'posts_per_page'         => $related_port_number,
			'no_found_rows'          => true,
			'post_status'            => 'publish',
			'ignore_sticky_posts'    => true,
			'update_post_term_cache' => false,
		);

		# Checking Related Posts Order ----------
		if( RDTheme::$options['related_post_sort'] ){

			$post_order = RDTheme::$options['related_post_sort'];

			if( $post_order == 'rand' ){

				$args['orderby'] = 'rand';
			}
			elseif( $post_order == 'views' ){

				$args['orderby']  = 'meta_value_num';
				$args['meta_key'] = 'woddingat_views';
			}
			elseif( $post_order == 'popular' ){

				$args['orderby'] = 'comment_count';
			}
			elseif( $post_order == 'modified' ){

				$args['orderby'] = 'modified';
				$args['order']   = 'ASC';
			}
			elseif( $post_order == 'recent' ){

				$args['orderby'] = '';
				$args['order']   = '';
			}
		}


		# Get related posts by author ----------
		if( $query_type == 'author' ){
			$args['author'] = get_the_author_meta( 'ID' );
		}

		# Get related posts by tags ----------
		elseif( $query_type == 'tag' ){
			$tags_ids  = array();
			$post_tags = get_the_terms( $post_id, 'post_tag' );

			if( ! empty( $post_tags ) ){
				foreach( $post_tags as $individual_tag ){
					$tags_ids[] = $individual_tag->term_id;
				}

				$args['tag__in'] = $tags_ids;
			}
		}

		# Get related posts by categories ----------
		else{
			
			$terms = get_the_terms( $post_id, 'woddingat_portfolio_category' );
			if ( $terms && ! is_wp_error( $terms ) ) {
			 
				$port_cat_links = array();
			 
				foreach ( $terms as $term ) {
					$port_cat_links[] = $term->term_id;
				}
			}
			
			$args['tax_query'] = array (
				array (
					'taxonomy' => 'woddingat_portfolio_category',
					'field'    => 'ID',
					'terms'    => $port_cat_links,
				)
			);

		}

		$slick_content = array( 
		    'slidesToShow'        => 3,
		    'slidesToShowTab'     => 2,
		    'slidesToShowMobile'  => 2,
		    'slidesToShowMobiles' => 1,
		    'autoplaySpeed'       => 2000,
		    'dots'                => false,
		    'arrows'              => false,
		    'autoplay'            => true,
		    'rtl'                 => false,
		);
		$slick_content = htmlspecialchars(wp_json_encode($slick_content), ENT_QUOTES, 'UTF-8');

		# Get the posts ----------
		$related_query = new wp_query( $args );
		
		if( $related_query->have_posts() ) { ?>
		<section class="more-works-wrap-layout1">
			<div class="container">
				<?php if( !empty( RDTheme::$options['port_related_title'] ) ) : ?>
				<h2 class="heading"><?php echo esc_html(  RDTheme::$options['port_related_title'] ); ?></h2>
				<?php endif; ?>
				<div class="more-works-carousel1" data-slick='<?php echo esc_attr( $slick_content ); ?>'>

					<?php
						while ( $related_query->have_posts() ) {
						$related_query->the_post();
						$cats = wp_get_post_terms( get_the_ID(), 'woddingat_portfolio_category', array( "fields" => "names" ) );
						$cats = implode( ', ', $cats ); 

					?>
					<div class="portfolio-box-layout3">
					<?php 
						if ( has_post_thumbnail() ){ ?>
						<div class="item-figure">
							<?php the_post_thumbnail( 'woddingat-size3' ); ?>
						</div>
					<?php } ?>
						<div class="item-content">
							<h3 class="item-title"><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h3>
							<p><?php echo wp_kses_post( $cats );?></p>
						</div>
					</div>
					<?php } ?>
				</div>
			</div>
		</section>
		<?php }
		wp_reset_postdata();
	}
}
?>