<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.1
 */

namespace radiustheme\woddingat;
use radiustheme\woddingat\inc\RDTheme;
use radiustheme\woddingat\inc\Helper;
use \WP_Query;
use Elementor\Plugin;

class Scripts {
	public $woddingat  = WODDINGAT_THEME_PREFIX;
	public $version = WODDINGAT_THEME_VERSION;	
	public function __construct() {
		add_action( 'wp_enqueue_scripts',    array( $this, 'register_scripts' ), 12 );
		add_action( 'wp_enqueue_scripts',    array( $this, 'enqueue_scripts' ), 15 );
		add_action( 'wp_enqueue_scripts',    array( $this, 'woddingat_enqueue_high_priority_scripts' ), 1500 );		
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_conditional_scripts' ), 1 );
		add_action( 'admin_enqueue_scripts', array( $this, 'woddingat_admin_scripts' ) );	
		add_action( 'template_include',      array( $this, 'under_construction_mode_enable'), 999 );
	}
	
	/**
	 * Maintenance Mode
	 */
	public function under_construction_mode_enable( $template ) {
	    $new_template = locate_template( array( 'construction.php' ) );
	    if ( Helper::is_under_construction_mode()  && '' != $new_template ) {
	    	return $new_template;
	    } else {
	    	return $template;
	    }
	}

	public function fonts_url() {
		$fonts_url = '';
	    $subsets = 'latin';
	    $bodyFont = 'Roboto';
	    $bodyFW = '400';
	    $menuFont = 'Roboto';
	    $menuFontW = '500';
	    $hFont = 'Cormorant';
	    $hFontW = '400';
	    $h1Font = '';
	    $h2Font = '';
	    $h3Font = '';
	    $h4Font = '';
	    $h5Font = '';
	    $h6Font = '';

	    // Body Font
	    $body_font  = json_decode( RDTheme::$options['typo_body'], true );
	    if ($body_font['font'] == 'Inherit') {
	    	$bodyFont = 'Roboto';
	    } else {
	    	$bodyFont = $body_font['font'];
	    }
	    $bodyFontW = $body_font['regularweight'];

	    // Menu Font
	    $menu_font  = json_decode( RDTheme::$options['typo_menu'], true );
	    if ($menu_font['font'] == 'Inherit') {
		    $menuFont = 'Roboto';
		} else {
	    	$menuFont = $menu_font['font'];
		}
	    $menuFontW = $menu_font['regularweight'];

	    // Heading Font Settings
	    $h_font  = json_decode( RDTheme::$options['typo_heading'], true );
	    if ($h_font['font'] == 'Inherit') {
		    $hFont = 'Cormorant';
		} else {
			$hFont = $h_font['font'];
		}
	    $hFontW = $h_font['regularweight'];
	    $h1_font  = json_decode( RDTheme::$options['typo_h1'], true );
	    $h2_font  = json_decode( RDTheme::$options['typo_h2'], true );
	    $h3_font  = json_decode( RDTheme::$options['typo_h3'], true );
	    $h4_font  = json_decode( RDTheme::$options['typo_h4'], true );
	    $h5_font  = json_decode( RDTheme::$options['typo_h5'], true );
	    $h6_font  = json_decode( RDTheme::$options['typo_h6'], true );

	    if ( 'off' !== _x( 'on', 'Google font: on or off', 'woddingat' ) ) {

		    if (!empty($h1_font['font'])) {
		        if ($h1_font['font'] == 'Inherit') {
				    $h1Font = $hFont;
				    $h1FontW = $hFontW;
				} else {
					$h1Font = $h2_font['font'];
		        	$h1FontW = $h1_font['regularweight'];
				}
		    } if (!empty($h2_font['font'])) {
		    	if ($h2_font['font'] == 'Inherit') {
				    $h2Font = $hFont;
				    $h2FontW = $hFontW;
				} else {
					$h2Font = $h2_font['font'];
		        	$h2FontW = $h2_font['regularweight'];
				}
		    } if (!empty($h3_font['font'])) {
		        if ($h3_font['font'] == 'Inherit') {
				    $h3Font = $hFont;
				    $h3FontW = $hFontW;
				} else {
					$h3Font = $h3_font['font'];
		        	$h3FontW = $h3_font['regularweight'];
				}
		    } if (!empty($h4_font['font'])) {
		        if ($h4_font['font'] == 'Inherit') {
				    $h4Font = $hFont;
				    $h4FontW = $hFontW;
				} else {
					$h4Font = $h4_font['font'];
		        	$h4FontW = $h4_font['regularweight'];
				}
		    } if (!empty($h5_font['font'])) {
		        if ($h5_font['font'] == 'Inherit') {
				    $h5Font = $hFont;
				    $h5FontW = $hFontW;
				} else {
					$h5Font = $h5_font['font'];
		        	$h5FontW = $h5_font['regularweight'];
				}
		    } if (!empty($h6_font['font'])) {
		    	 if ($h6_font['font'] == 'Inherit') {
				    $h6Font = $hFont;
				    $h6FontW = $hFontW;
				} else {
					$h6Font = $h6_font['font'];
		        	$h6FontW = $h6_font['regularweight'];
				}
		    }

		    $check_families = array();
		    $font_families = array();

			// Body Font
			if ( 'off' !== $bodyFont )
				$font_families[] = $bodyFont.':300,500,700,'.$bodyFW;
				$check_families[] = $bodyFont;

			// Menu Font
			if ( 'off' !== $menuFont )
				if ( !in_array( $menuFont, $check_families ) ) {
					$font_families[] = $menuFont.':500,'.$menuFontW;
					$check_families[] = $menuFont;
				}

			// Heading Font
			if ( 'off' !== $hFont )
				if (!in_array( $hFont, $check_families )) {
					$font_families[] = $hFont.':300,500,600,700,'.$hFontW;
					$check_families[] = $hFont;
				}

			// Heading 1 Font
			if (!empty($h1_font['font'])) {
				if ( 'off' !== $h1Font )
					if (!in_array( $h1Font, $check_families )) {
						$font_families[] = $h1Font.':'.$h1FontW;
						$check_families[] = $h1Font;
					}
			}
			// Heading 2 Font
			if (!empty($h2_font['font'])) {
				if ( 'off' !== $h2Font )
					if (!in_array( $h2Font, $check_families )) {
						$font_families[] = $h2Font.':'.$h2FontW;
						$check_families[] = $h2Font;
					}
			}
			// Heading 3 Font
			if (!empty($h3_font['font'])) {
				if ( 'off' !== $h3Font )
					if (!in_array( $h3Font, $check_families )) {
						$font_families[] = $h3Font.':'.$h3FontW;
						$check_families[] = $h3Font;
					}
			}
			// Heading 4 Font
			if (!empty($h4_font['font'])) {
				if ( 'off' !== $h4Font )
					if (!in_array( $h4Font, $check_families )) {
						$font_families[] = $h4Font.':'.$h4FontW;
						$check_families[] = $h4Font;
					}
			}
			// Heading 5 Font
			if (!empty($h5_font['font'])) {
				if ( 'off' !== $h5Font )
					if (!in_array( $h5Font, $check_families )) {
						$font_families[] = $h5Font.':'.$h5FontW;
						$check_families[] = $h5Font;
					}
			}
			// Heading 6 Font
			if (!empty($h6_font['font'])) {
				if ( 'off' !== $h6Font )
					if (!in_array( $h6Font, $check_families )) {
						$font_families[] = $h6Font.':'.$h6FontW;
						$check_families[] = $h6Font;
					}
			}
		    $final_fonts = array_unique( $font_families );
		    $query_args = array(
		        'family' => urlencode( implode( '|', $final_fonts ) ),
		        'display' => urlencode( 'fallback' ),
		    );

		    $fonts_url = add_query_arg( $query_args, "//fonts.googleapis.com/css" );
		}
		
    	return esc_url_raw( $fonts_url );
	}


	public function woddingat_get_maybe_rtl( $filename ){
		$file = get_template_directory_uri() . '/assets/';
		if ( is_rtl() ) {
			return $file . 'rtl-css/' . $filename;
		}
		else {
			return $file . 'css/' . $filename;
		} 
	}

	public function woddingat_enqueue_high_priority_scripts(){
		if ( is_rtl() ) {
			wp_enqueue_style( 'rtlcss', Helper::get_css( 'rtl' ), array(), $this->version );
		}
	}

	public function register_scripts(){
		/* Deregister */
		wp_deregister_style( 'font-awesome' );
		wp_deregister_style( 'elementor-waypoints' );
		
		/* = CSS
		======================================================================*/
		// Bootstrap css
		wp_register_style( 'bootstrap',         Helper::get_css( 'bootstrap.min' ), array(), $this->version );
		// FontAwesome css
		wp_register_style( 'font-awesome',      Helper::get_css( 'all.min' ), array(), $this->version );
		// Flat Icon css
		wp_register_style( 'flaticon',          Helper::get_css( 'flaticon' ), array(), $this->version );
		// Nivo Slider
		wp_register_style( 'nivo-slider',       Helper::get_css( 'nivo-slider' ), array(), $this->version );
		// Magnific Popup
		wp_register_style( 'magnific-popup',    Helper::get_css( 'magnific-popup' ), array(), $this->version );
		// Slick Slider
		wp_register_style( 'slick',             Helper::get_css( 'slick' ), array(), $this->version );
		// pagepiling
		wp_register_style( 'pagepiling',        Helper::get_css( 'jquery.pagepiling.min' ), array(), $this->version );
		// Default css
		wp_register_style( 'woddingat-default', Helper::get_css( 'default' ), array(), $this->version );
		// Main Theme Style
		wp_register_style( 'woddingat-style',   $this->woddingat_get_maybe_rtl( 'style.css' ), array(), $this->version );


		/* = JS 
		======================================================================*/
		// Isotop For Filtering
		wp_register_script( 'isotope-pkgd',         Helper::get_js( 'isotope.pkgd.min' ), array( 'jquery', 'imagesloaded' ), $this->version, true );
		// Wow
		wp_register_script( 'wow',      		    Helper::get_js( 'wow.min' ), array( 'jquery', 'imagesloaded' ), $this->version, true );
		// Magnific Popup
		wp_register_script( 'magnific-popup',       Helper::get_js( 'jquery.magnific-popup.min' ), array( 'jquery' ), $this->version, true );
		// Theia Sticky Sidebar
		wp_register_script( 'theia-sticky-sidebar', Helper::get_js( 'theia-sticky-sidebar.min' ), array( 'jquery' ), $this->version, true );
		// Nivo Slider
		wp_register_script( 'nivo-slider',          Helper::get_js( 'jquery.nivo.slider' ), array( 'jquery' ), $this->version, true );
		// Slick Slider
		wp_register_script( 'slick',                Helper::get_js( 'slick.min' ), array( 'jquery' ), $this->version, true );
		// Countdown
		wp_register_script( 'countdown',            Helper::get_js( 'jquery.countdown.min' ), array( 'jquery' ), $this->version, true );
		// Bootstrap
		wp_register_script( 'bootstrap',            Helper::get_js( 'bootstrap.min' ), array( 'jquery' ), $this->version, true );
		// Pagepiling
		wp_register_script( 'pagepiling',           Helper::get_js( 'jquery.pagepiling.min' ), array( 'jquery' ), $this->version, true );
		// Main js
		wp_register_script( 'woddingat-main',       Helper::get_js( 'main' ), array( 'jquery' ), $this->version, true );

	}  
     
	public function enqueue_scripts() {	
		/*CSS*/

		$this->elementor_scripts();

		wp_enqueue_style( 'woddingat-gfonts', $this->fonts_url(), array(), $this->version );
		wp_enqueue_style( 'bootstrap' );
		wp_enqueue_style( 'font-awesome' );
		wp_enqueue_style( 'flaticon' );
		wp_enqueue_style( 'nivo-slider' );
		wp_enqueue_style( 'magnific-popup' );
		wp_enqueue_style( 'slick' );
		wp_enqueue_style( 'pagepiling' );
		wp_enqueue_style( 'woddingat-default' );
		$this->conditional_scripts(); // Conditional Scripts
		wp_enqueue_style( 'woddingat-style' );
		$this->dynamic_style(); // Dynamic style

		/*JS*/
		wp_enqueue_script( 'imagesloaded' );
		wp_enqueue_script( 'wow' );
		wp_enqueue_script( 'magnific-popup' );
		wp_enqueue_script( 'theia-sticky-sidebar' );
		wp_enqueue_script( 'isotope-pkgd' );
		wp_enqueue_script( 'nivo-slider' );
		wp_enqueue_script( 'slick' );
		wp_enqueue_script( 'pagepiling' );
		wp_enqueue_script( 'countdown' );
		wp_enqueue_script( 'bootstrap' );
		wp_enqueue_script( 'woddingat-main' );
		$this->localized_scripts(); // Localization
		
	}

	private function conditional_scripts(){
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
	
	public function admin_conditional_scripts(){		
		wp_enqueue_style( 'woddingat-gfonts', $this->fonts_url(), array(), $this->version );
		wp_enqueue_script('jquery-ui-tabs');		
		wp_enqueue_style('wp-color-picker');
	}

	public function woddingat_admin_scripts(){		
		wp_enqueue_style( 'flaticon',  Helper::get_css( 'flaticon' ), array(), $this->version );
	}

	private function localized_scripts(){
		// Localization
		$rt_the_logo_dark = empty( Helper::rt_the_logo_dark() ) ? get_bloginfo( 'name' ) : Helper::rt_the_logo_dark();
		$adminajax 	      = esc_url( admin_url('admin-ajax.php') );
		$localize_data    = array(
			'ajaxurl'	  => $adminajax,
			'hasAdminBar' => is_admin_bar_showing() ? 1 : 0,
			'headerStyle' => RDTheme::$header_style,
			'siteLogo'    => '<div class="mobile-menu-nav-back"><a class="logo-mobile" href="' . esc_url( home_url( '/' ) ) . '" alt="' . esc_attr( get_bloginfo( 'title' ) ) . '" class="img-fluid">' .wp_kses( $rt_the_logo_dark, 'alltext_allow' ). '</a></div>',
			// Ajax
			'ajaxURL'     => admin_url('admin-ajax.php'),
			'nonce'       => wp_create_nonce( 'woddingat-nonce' ),
			'rtl'            => is_rtl() ? true : false,
		);
		wp_localize_script( $this->woddingat . '-main', 'WoddingatObj', $localize_data );

	}

	public function elementor_scripts() {
		if ( !did_action( 'elementor/loaded' ) ) {
			return;
		}
		if ( Plugin::$instance->preview->is_preview_mode() ) {
			wp_enqueue_style( 'slick' );			
			wp_enqueue_script( 'slick' );			
		}
	}

	private function dynamic_style(){
		$dynamic_css  = $this->template_style();
		ob_start();
		Helper::requires( 'dynamic-style.php' );
		$dynamic_css .= ob_get_clean();
		$dynamic_css  = $this->minified_css( $dynamic_css );
		wp_register_style( $this->woddingat . '-dynamic', false );
		wp_enqueue_style( $this->woddingat . '-dynamic' );
		wp_add_inline_style( $this->woddingat . '-dynamic', $dynamic_css );
	}

	private function minified_css( $css ) {
		/* remove comments */
		$css = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $css );
		/* remove tabs, spaces, newlines, etc. */
		$css = str_replace( array( "\r\n", "\r", "\n", "\t", '  ', '    ', '    ' ), ' ', $css );
		return $css;
	}

	private function template_style(){
		$style = '';
		if ( is_single() ) {
			if ( RDTheme::$bgtype === 'bgimg' ) {
				$opacity = RDTheme::$overlayopacity/100;
				$style .= '.single .inner-page-banner { background-image: url(' . RDTheme::$bgimg . ')}';
				$style .= '.single .inner-page-banner:before { background-color: ' . RDTheme::$bgimgoverlay . '}';
				$style .= '.single .inner-page-banner:before { opacity: ' . $opacity . '}';
			}
			else {
				if ( !empty( RDTheme::$bgcolor ) ) {
					$style .= '.single .inner-page-banner.bg-color { background-color: ' . RDTheme::$bgcolor . '}';
				}
			}
		} else {
			if ( RDTheme::$bgtype === 'bgimg' ) {
				$opacity = RDTheme::$overlayopacity/100;
				$style .= '.inner-page-banner { background-image: url(' . RDTheme::$bgimg . ')}';
				$style .= '.inner-page-banner:before { background-color: ' . RDTheme::$bgimgoverlay . '}';
				$style .= '.inner-page-banner:before { opacity: ' . $opacity . '}';
			}
			else {
				$style .= '.inner-page-banner.bg-color { background-color: ' . RDTheme::$bgcolor . '}';
			}
		}
		
		if ( RDTheme::$inner_padding_top) {
			$style .= '.inner-page-banner {padding-top:'. RDTheme::$inner_padding_top . 'px;}';
		}
		if ( RDTheme::$inner_padding_bottom) {
			$style .= '.inner-page-banner {padding-bottom:'. RDTheme::$inner_padding_bottom . 'px;}';
		}


		/* = Footer 1
        =======================================================*/
		if ( RDTheme::$options['footer1_bg_img'] && RDTheme::$options['display_footer1_bg_image'] === 1 ) {
			$f1_bg = wp_get_attachment_image_src( RDTheme::$options['footer1_bg_img'], 'full', true );
			$style .= '.footer-layout1:before { background-image: url(' . $f1_bg[0] . ')}';
		}
		if ( RDTheme::$options['footer1_bg_img2'] && RDTheme::$options['display_footer1_bg_image'] === 1 ) {
			$f1_bg = wp_get_attachment_image_src( RDTheme::$options['footer1_bg_img2'], 'full', true );
			$style .= '.footer-layout1 { background-image: url(' . $f1_bg[0] . ')}';
		}
		if ( RDTheme::$options['footer1_bg_color']) {
			$style .= '.footer-layout1 { background-color: ' . RDTheme::$options['footer1_bg_color'] . '}';
		}
		if ( RDTheme::$options['footer1_bg_opacity']) {
			$f1o = RDTheme::$options['footer1_bg_opacity']/100;
			$style .= '.footer-layout1 { opacity: ' . $f1o . '}';
			$style .= '.footer-layout1:before { opacity: ' . $f1o . '}';
		}
		if ( RDTheme::$options['footer1_padding_top'] ) {
			$style .= '.footer-layout1 {padding-top:'. RDTheme::$options['footer1_padding_top'] . 'px;}';
		}
		if ( RDTheme::$options['footer1_padding_bottom'] ) {
			$style .= '.footer-layout1 {padding-bottom:'. RDTheme::$options['footer1_padding_bottom'] . 'px;}';
		}

		/* = Footer 2
        =======================================================*/
		if ( RDTheme::$options['footer2_bg_color']) {
			$style .= '.footer-layout2 { background-color: ' . RDTheme::$options['footer2_bg_color'] . '}';
		}
		if ( RDTheme::$options['footer2_bg_opacity']) {
			$f1o = RDTheme::$options['footer2_bg_opacity']/100;
			$style .= '.footer-layout2 { opacity: ' . $f1o . '}';
		}
		if ( RDTheme::$options['footer2_padding_top'] ) {
			$style .= '.footer-layout2 {padding-top:'. RDTheme::$options['footer2_padding_top'] . 'px;}';
		}
		if ( RDTheme::$options['footer2_padding_bottom'] ) {
			$style .= '.footer-layout2 {padding-bottom:'. RDTheme::$options['footer2_padding_bottom'] . 'px;}';
		}
		
		return $style;
	}	
	
}
new Scripts;