<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/about-box/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;


if ( ! defined( 'ABSPATH' ) ) exit;

class Address extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Address', 'woddingat-core' );
		$this->rt_base = 'rt-address';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_invitation',
				'mode'    => 'section_start',
				'label'   => __( 'General', 'woddingat-core' ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'title',
				'label'   => __( 'Title', 'woddingat-core' ),
				'default' => __( 'New York Office', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'        => Controls_Manager::ICONS,
				'id'        => 'address_icon',
				'label'       => esc_html__( 'Address Icon', 'woddingat-core' ),
				'description' => esc_html__( 'Select icon', 'woddingat-core' ),
				'default'     => [
				      'value'   => 'flaticon-map-locator',
				      'library' => 'fa-solid',
				  	],
			),
			array(
				'type'    => Controls_Manager::TEXTAREA,
				'id'      => 'address',
				'label'   => __( 'Address', 'woddingat-core' ),
				'default' => __( '198 West 21th Street, Suite 721 New York NY 10010', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'        => Controls_Manager::ICONS,
				'id'        => 'email_icon',
				'label'       => esc_html__( 'Email Icon', 'woddingat-core' ),
				'description' => esc_html__( 'Select icon', 'woddingat-core' ),
				'default'     => [
				      'value'   => 'flaticon-envelope',
				      'library' => 'fa-solid',
				  	],
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'email',
				'label'   => __( 'Email', 'woddingat-core' ),
				'default' => __( 'youremail@yourdomain.com', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'        => Controls_Manager::ICONS,
				'id'        => 'phone_icon',
				'label'       => esc_html__( 'Phone Icon', 'woddingat-core' ),
				'description' => esc_html__( 'Select icon', 'woddingat-core' ),
				'default'     => [
				      'value'   => 'flaticon-phone-call',
				      'library' => 'fa-solid',
				  	],
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'phone',
				'label'   => __( 'Phone', 'woddingat-core' ),
				'default' => __( '+88 (0) 101 0000 000', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'mode' => 'section_end',
			),
			// Style
			array(
				'id'      => 'box_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Box Style', 'woddingat-core' ),
			),
			array(
				'id'      => 'box_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .address-box-layout1' => 'background-color: {{VALUE}} !important' ),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'woddingat-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .address-box-layout1 .title' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .address-box-layout1 .title',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .address-box-layout1 .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .address-box-layout1 .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'address_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Address', 'woddingat-core' ),
			),
			array(
				'id'      => 'address_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .address-box-layout1 .address' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'address_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .address-box-layout1 .address',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'phone_email_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Phone & Email', 'woddingat-core' ),
			),
			array(
				'id'      => 'phone_email_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .address-box-layout1 .address-info li' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .address-box-layout1 .address-info li a' => 'color: {{VALUE}} !important',
					 ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'phone_email_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .address-box-layout1 .address-info li, {{WRAPPER}} .address-box-layout1 .address-info li a',
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$template = 'view';

		return $this->rt_template( $template, $data );
	}
}