<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/about-box/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;


if ( ! defined( 'ABSPATH' ) ) exit;

class Carousel_Gallery extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Carousel Gallery', 'woddingat-core' );
		$this->rt_base = 'rt-carousel-gallery';
		parent::__construct( $data, $args );
	}

	public function rt_load_scripts(){
		wp_enqueue_style(  'slick');			
	    wp_enqueue_script( 'slick' );
	}

	public function rt_fields(){

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'img1', [
				'type' 		  => Controls_Manager::MEDIA,
				'label'   => esc_html__( 'Image 1', 'woddingat-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'woddingat-core' ),
			]
		);
		$repeater->add_control(
			'img2', [
				'type' 		  => Controls_Manager::MEDIA,
				'label'   => esc_html__( 'Image 2', 'woddingat-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'woddingat-core' ),
			]
		);
		$repeater->add_control(
			'title', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Title', 'woddingat-core' ),
				'default'     => esc_html__( 'LOVE FOREVER', 'woddingat-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'content', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Content', 'woddingat-core' ),
				'default'     => esc_html__( 'Grursus mal suada faci lisis consectetur elit.', 'woddingat-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'url', [
				'type' 		  => Controls_Manager::URL,
				'label'       => esc_html__( 'Link', 'woddingat-core' ),
				'placeholder' => 'https://your-link.com',
				'label_block' => true,
			]
		);

		$fields = array(
			array(
				'id'      => 'sec_carousel_gallery',
				'mode'    => 'section_start',
				'label'   => __( 'Carousel Gallery', 'woddingat-core' ),
			),
			array (
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'slider_items',
				'label'   => esc_html__( 'Add as many items as you want', 'woddingat-core' ),
				'fields'  => $repeater->get_controls(),
		       	'default' => [
					[
						'title' => __( 'LOVE FOREVER', 'woddingat-core' ),
						'content'  => __( 'Grursus mal suada faci lisis consectetur elit.', 'woddingat-core' ),
					],
					[
						'title' => __( 'LOVE FOREVER', 'woddingat-core' ),
						'content'  => __( 'Grursus mal suada faci lisis consectetur elit.', 'woddingat-core' ),
					],
					[
						'title' => __( 'LOVE FOREVER', 'woddingat-core' ),
						'content'  => __( 'Grursus mal suada faci lisis consectetur elit.', 'woddingat-core' ),
					],
				],
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'mode'        => 'section_start',
				'id'          => 'sec_slider',
				'label'       => esc_html__( 'Slider Options', 'woddingat-core' ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_autoplay',
				'label'       => esc_html__( 'Autoplay', 'woddingat-core' ),
				'label_on'    => esc_html__( 'On', 'woddingat-core' ),
				'label_off'   => esc_html__( 'Off', 'woddingat-core' ),
				'description' => esc_html__( 'Enable or disable autoplay. Default: On', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slider_autoplay_speed',
				'label'   => esc_html__( 'Autoplay Speed', 'woddingat-core' ),
				'options' => $this->rt_autoplay_speed(),
				'default' => '2000',
				'description' => esc_html__( 'Select any value for autopaly speed. Default: 2000', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slide_to_show',
				'label'   => esc_html__( 'Slide To Show', 'woddingat-core' ),
				'options' => $this->rt_number_options(),
				'default' => '2',
				'description' => esc_html__( 'Select any value for desktop device show. Default: 2', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slide_to_show_tab',
				'label'   => esc_html__( 'Tab View', 'woddingat-core' ),
				'options' => $this->rt_number_options(),
				'default' => '2',
				'description' => esc_html__( 'Select any value for tab device show. Default: 2', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slide_to_show_mobile',
				'label'   => esc_html__( 'Mobile View', 'woddingat-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'Select any value for mobile device show. Default: 1', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slide_to_show_small_mobile',
				'label'   => esc_html__( 'Mobile Small View', 'woddingat-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'Select any value for small mobile device show. Default: 1', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'mode' => 'section_end',
			),
			// Style
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'woddingat-core' ),
			),
			array(
				'id'      => 'title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Normal', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .carousel-portfolio-box .content-box .title a' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .carousel-portfolio-box .content-box .title a',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .carousel-portfolio-box .content-box .title a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .carousel-portfolio-box .content-box .title a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'id'      => 'title_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .carousel-portfolio-box .content-box .title a:hover' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'content_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Content', 'woddingat-core' ),
			),
			array(
				'id'      => 'content_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .carousel-portfolio-box .content-box .sub-title' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'content_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .carousel-portfolio-box .content-box .sub-title',
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$this->rt_load_scripts();

		$template = 'view';

		return $this->rt_template( $template, $data );
	}
}