<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/counter/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Counter extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Counter', 'woddingat-core' );
		$this->rt_base = 'rt-counter';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_general',
				'mode'    => 'section_start',
				'label'   => __( 'Counter', 'woddingat-core' ),
			),
			// Number
			array(
				'id'      => 'number',
				'type'    => Controls_Manager::TEXT,
				'label'   => __( 'Number', 'woddingat-core' ),
				'default' => __( '75', 'woddingat-core' ),
				'label_block' => true,
			),
			// Title
			array(
				'id'      => 'title',
				'type'    => Controls_Manager::TEXT,
				'label'   => __( 'Title', 'woddingat-core' ),
				'default' => __( 'Decoration', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'sec_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Style', 'woddingat-core' ),
			),
			// Number Style
			array(
				'id'      => 'number_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Number Style', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'number_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Number', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .about-skill .progress-bar > span' => 'color: {{VALUE}}'
				),
			),
			array(
				'name'     => 'number_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .about-skill .progress-bar > span',
			),
			// Title Style
			array(
				'id'      => 'title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Title Style', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .about-skill .progress .lead' => 'color: {{VALUE}}'
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .about-skill .progress .lead',
			),
			// Box Style
			array(
				'id'      => 'box_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Box', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'box_bgcolor',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .about-skill .progress-bar' => 'background-color: {{VALUE}}'
				),
			),
			array(
				'id'      => 'box_border_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .about-skill .progress' => 'border-color: {{VALUE}}'
				),
			),
			array(
			    'id'      => 'box_height',
			    'mode' 	  => 'responsive',
			    'type' => Controls_Manager::SLIDER,
			    'label'   => __( 'Height', 'woddingat-core' ),                 
				'range' => [
					'px' => [
						'min' => 100,
						'max' => 1000,
					],
				],
			    'selectors' => [
					'{{WRAPPER}} .about-skill .progress' => 'height: {{SIZE}}{{UNIT}};',
				],
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	public function counter(){
		wp_enqueue_script( 'countdown' );
	}

	protected function render() {
		$data = $this->get_settings();
		$this->counter();

		$template = 'view';

		return $this->rt_template( $template, $data );
	}
}