<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Features extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = esc_html__( 'Features', 'woddingat-core' );
		$this->rt_base = 'rt-features';	
		parent::__construct( $data, $args );
	}

	public function rt_fields(){

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'title', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Title', 'woddingat-core' ),
				'default'     => esc_html__( 'FASHION', 'woddingat-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'fnumber', [
				'type' 		  => Controls_Manager::NUMBER,
				'label'       => esc_html__( 'Number', 'woddingat-core' ),
				'default'     => esc_html__( '01', 'woddingat-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'feature_img', [
				'type' 		  => Controls_Manager::MEDIA,
				'label'   => esc_html__( 'Image', 'woddingat-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'woddingat-core' ),
			]
		);
		$repeater->add_control(
			'link_text', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Link Text', 'woddingat-core' ),
				'default'     => esc_html__( 'View Case', 'woddingat-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'case_link', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Case Link', 'woddingat-core' ),
				'default'     => '#',
				'label_block' => true,
			]
		);
		$fields = array(
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_general',
				'label'   => __( 'General', 'woddingat-core' ),
			),
			array (
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'features_list',
				'label'   => esc_html__( 'Add as many feature as you want', 'woddingat-core' ),
				'fields'  => $repeater->get_controls(),
		       	'default' => [
					[
						'title' => __( 'FASHION', 'woddingat-core' ),
						'fnumber'  => __( '01', 'woddingat-core' ),
						'link_text'  => __( 'View Case', 'woddingat-core' ),
					],
					[
						'title' => __( 'SPRING', 'woddingat-core' ),
						'fnumber'  => __( '02', 'woddingat-core' ),
						'link_text'  => __( 'View Case', 'woddingat-core' ),
					],[
						'title' => __( 'WEDDING', 'woddingat-core' ),
						'fnumber'  => __( '03', 'woddingat-core' ),
						'link_text'  => __( 'View Case', 'woddingat-core' ),
					],[
						'title' => __( 'EVENT', 'woddingat-core' ),
						'fnumber'  => __( '04', 'woddingat-core' ),
						'link_text'  => __( 'View Case', 'woddingat-core' ),
					],
				],
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'box_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Box', 'woddingat-core' ),
			),
			array(
				'id'      => 'box_bg',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .feature-box-layout1' => 'background-color: {{VALUE}} !important' ),
			),
			array(
				'id'      => 'line_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Line Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .feature-box-layout1.nav li a:before' => 'background-color: {{VALUE}} !important' ),
			),
	        array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'number_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Number', 'woddingat-core' ),
			),
			array(
				'id'      => 'number_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .feature-box-layout1.nav li span' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'number_typo',
				'label'    => esc_html__( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .feature-box-layout1.nav li span',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'woddingat-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .feature-box-layout1.nav li a' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => esc_html__( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .feature-box-layout1.nav li a',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'case_text_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Case Text', 'woddingat-core' ),
			),
			array(
				'id'      => 'case_text_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Normal', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'case_text_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .feature-box-layout1.tab-content .tab-pane a' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'case_text_typo',
				'label'    => esc_html__( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .feature-box-layout1.tab-content .tab-pane a',
			),
			array(
				'id'      => 'case_text_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'case_text_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .feature-box-layout1.tab-content .tab-pane a:hover' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'icon_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Icon', 'woddingat-core' ),
			),
			array(
				'id'      => 'icon_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Normal', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'icon_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .feature-box-layout1.tab-content .tab-pane a i' => 'color: {{VALUE}} !important' ),
			),
			array(
				'id'      => 'icon_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .feature-box-layout1.tab-content .tab-pane a span' => 'background-color: {{VALUE}} !important' ),
			),
			array(
				'id'      => 'ico_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'icon_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .feature-box-layout1.tab-content .tab-pane a:hover span' => 'color: {{VALUE}} !important' ),
			),
			array(
				'id'      => 'icon_bg_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .feature-box-layout1.tab-content .tab-pane a:hover span' => 'background-color: {{VALUE}} !important' ),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}
	protected function render() {
		$data 	  = $this->get_settings();

		$template = 'view';
		
		return $this->rt_template( $template, $data );		
	}
}