<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/about-box/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;


if ( ! defined( 'ABSPATH' ) ) exit;

class Gallery extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Gallery', 'woddingat-core' );
		$this->rt_base = 'rt-gallery';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'gallery_type', [
				'type' 		  => Controls_Manager::SELECT,
				'label'       => esc_html__( 'Gallery Type', 'woddingat-core' ),
				'options' => [
					'normal' => esc_html__( 'Normal', 'woddingat-core' ),
					'video'  => esc_html__( 'Video', 'woddingat-core' ),
					'slider' => esc_html__( 'Slider', 'woddingat-core' ),
				],
				'default' => 'normal',
			]
		);
		$repeater->add_control(
			'single_img', [
				'type' 		  => Controls_Manager::MEDIA,
				'label'   => esc_html__( 'Image', 'woddingat-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'woddingat-core' ),
				'label_block' => true,
				'conditions' => [
					'terms' => [
						[
							'name' => 'gallery_type',
							'operator' => '!=',
							'value' => 'slider',
						],
					],
				],
			]
		);
		$repeater->add_control(
			'slider_img', [
				'type' 		  => Controls_Manager::GALLERY,
				'label'   => esc_html__( 'Slider Image', 'woddingat-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'woddingat-core' ),
				'conditions' => [
					'terms' => [
						[
							'name' => 'gallery_type',
							'value' => 'slider',
						],
					],
				],
			]
		);
		$repeater->add_control(
			'url', [
				'type' 		  => Controls_Manager::URL,
				'label'       => esc_html__( 'Video Link', 'woddingat-core' ),
				'placeholder' => 'https://your-link.com',
				'label_block' => true,
				'conditions' => [
					'terms' => [
						[
							'name' => 'gallery_type',
							'value' => 'video',
						],
					],
				],
			]
		);

		$fields = array(
			array(
				'id'      => 'sec_gallery',
				'mode'    => 'section_start',
				'label'   => __( 'Gallery', 'woddingat-core' ),
			),
			array (
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'gallery_items',
				'label'   => esc_html__( 'Add as many items as you want', 'woddingat-core' ),
				'fields'  => $repeater->get_controls(),
			),
			array(
				'mode' => 'section_end',
			),
			// Style
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'woddingat-core' ),
			),
			array(
				'id'      => 'title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Normal', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .carousel-portfolio-box .content-box .title a' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .carousel-portfolio-box .content-box .title a',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .carousel-portfolio-box .content-box .title a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .carousel-portfolio-box .content-box .title a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'id'      => 'title_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .carousel-portfolio-box .content-box .title a:hover' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$template = 'view';

		return $this->rt_template( $template, $data );
	}
}