<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/about-box/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;


if ( ! defined( 'ABSPATH' ) ) exit;

class Invitation extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Invitation', 'woddingat-core' );
		$this->rt_base = 'rt-invitation';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_invitation',
				'mode'    => 'section_start',
				'label'   => __( 'General', 'woddingat-core' ),
			),
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'image',
				'label'   => esc_html__( 'Image', 'woddingat-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'woddingat-core' ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'title',
				'label'   => __( 'Title', 'woddingat-core' ),
				'default' => __( 'Milana &amp; Nicholas', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'sub_title',
				'label'   => __( 'Sub Title', 'woddingat-core' ),
				'default' => __( 'Save the Date', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'date',
				'label'   => __( 'Date', 'woddingat-core' ),
				'default' => __( 'Sunday, 05 November 2017', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'time',
				'label'   => __( 'Time', 'woddingat-core' ),
				'default' => __( '17:00 PM – 20:00 PM', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'address1',
				'label'   => __( 'Address 1', 'woddingat-core' ),
				'default' => __( '1234 Redwood Court Street,', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'address2',
				'label'   => __( 'Address 2', 'woddingat-core' ),
				'default' => __( 'Auburn, WA 98092', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'btntext',
				'label'   => __( 'Button Text', 'woddingat-core' ),
				'default' => __( 'RSVP NOW', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'  => Controls_Manager::URL,
				'id'    => 'url',
				'label' => __( 'Button Link', 'woddingat-core' ),
				'placeholder' => 'https://your-link.com',
			),
			array(
				'mode' => 'section_end',
			),
			// Style
			array(
				'id'      => 'box_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Box Style', 'woddingat-core' ),
			),
			array(
				'id'      => 'box_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .invitation-box-layout1 .invitation-inner-box' => 'background-color: {{VALUE}} !important' ),
			),
			array(
				'name'     => 'box_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .invitation-box-layout1 .invitation-inner-box',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'woddingat-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .invitation-box-layout1 .invitation-inner-box .title' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .invitation-box-layout1 .invitation-inner-box .title',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .invitation-box-layout1 .invitation-inner-box .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .invitation-box-layout1 .invitation-inner-box .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'sub_title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Sub Title', 'woddingat-core' ),
			),
			array(
				'id'      => 'sub_title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .invitation-box-layout1 .invitation-inner-box .sub-title' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'sub_title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .invitation-box-layout1 .invitation-inner-box .sub-title',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'date_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Date & Address', 'woddingat-core' ),
			),
			array(
				'id'      => 'date_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .invitation-box-layout1 .invitation-inner-box .address-info li' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'date_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .invitation-box-layout1 .invitation-inner-box .address-info li',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'btn_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Button', 'woddingat-core' ),
			),
			array(
				'id'      => 'btn_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .invitation-inner-box .btn-fill' => 'color: {{VALUE}}!important;' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'btn_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .invitation-inner-box .btn-fill',
			),
			array(
				'id'      => 'btn_bgcolor',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .invitation-inner-box .btn-fill' => 'background-color: {{VALUE}}' ),
			),
			array(
				'id'      => 'btn_border_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .invitation-inner-box .btn-fill > span' => 'border-color: {{VALUE}}' ),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$template = 'view';

		return $this->rt_template( $template, $data );
	}
}