<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;
use radiustheme\woddingat\inc\Helper;

use Elementor\Utils;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Image_Size;

if ( ! defined( 'ABSPATH' ) ) exit;

class Portfolio_Masonry extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Portfolio Masonry', 'woddingat-core' );
		$this->rt_base = 'rt-portfolio-masonry';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$cpt               = WODDINGAT_CORE_CPT;
        $terms             = get_terms(array('taxonomy' => "{$cpt}_portfolio_category", 'fields' => 'id=>name'));
        $category_dropdown = array('0' => esc_html__('All Categories', 'woddingat-core'));
        foreach ($terms as $id => $name) {
            $category_dropdown[$id] = $name;
        }

        $posts = get_posts( ['post_type' => "{$cpt}_portfolio", 'posts_per_page' => -1, 'orderby' => 'title','order' => 'ASC','post_status' => 'publish','suppress_filters' => false]);
	    $posts_dropdown = [];
	    foreach ( $posts as $post ) {
	      $posts_dropdown[$post->ID] = $post->post_title;
	    }
	    
		$fields = array(
			array(
				'id'      => 'sec_rt_mpfolio',
				'mode'    => 'section_start',
				'label'   => esc_html__( 'Masonry Portfolio', 'woddingat-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'woddingat-core' ),
				'options' => array(
					'style1' => esc_html__( 'Layout 1', 'woddingat-core' ),
					'style2' => esc_html__( 'Layout 2', 'woddingat-core' ),
				),
				'default' => 'style1',
				'label_block' => true,
			),
			array(
                'type'     => Controls_Manager::SELECT2,
                'id'       => 'category_list',
                'label'    => esc_html__('Categories', 'woddingat-core'),
                'options'  => $category_dropdown,
                'default'  => '0',
                'multiple' => true,
                'label_block' => true,
                'condition' => array( 'style' => array( 'style2' ) ),
            ),
            array(
                'type'     => Controls_Manager::SELECT2,
                'id'       => 'single_post',
                'label'    => esc_html__('Select Post', 'woddingat-core'),
                'options'  => $posts_dropdown,
                'default'  => '0',
                'multiple' => false,
                'label_block' => true,
                'condition' => array( 'style' => array( 'style1' ) ),
            ),
            array(
				'type' 				=> Controls_Manager::SLIDER,
				'mode' 				=> 'responsive',
				'id'      		=> 'box_height',
				'label'   		=> esc_html__( 'Height', 'woddingat-core' ),
				'size_units' => array( 'px' ),
				 'range' => [
				 'px' => [
				   'min' => 0,
				   'max' => 800,
				 ],
			   ],
			   
				'default' => array(
				'unit' => 'px',
				'size' => 270,
				),
				'selectors' => array(
					'{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-figure' => 'height: {{SIZE}}{{UNIT}};',	
					'{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-figure img' => 'height: inherit;object-fit:cover;',						
				),
				'condition' => array( 'style' => array( 'style1' ) ),
			),
            array(
                'type'        => Controls_Manager::NUMBER,
                'id'          => 'number',
                'label'       => esc_html__('Total number of Portfolio', 'woddingat-core'),
                'default'     => 6,
                'description' => esc_html__('Write -1 to show all', 'woddingat-core'),
                'label_block' => true,
                'condition' => array( 'style' => array( 'style2' ) ),
            ),
            array(
                'type'        => Controls_Manager::SWITCHER,
                'id'          => 'category_display',
                'label'       => esc_html__('Category Display', 'woddingat-core'),
                'label_on'    => esc_html__('On', 'woddingat-core'),
                'label_off'   => esc_html__('Off', 'woddingat-core'),
                'default'     => 'yes',
                'description' => esc_html__('Categorys. Default: On', 'woddingat-core'),
            ),
            array(
                'mode' => 'section_end',
            ),		
			// Style
			array(
				'id'      => 'content_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Style', 'woddingat-core' ),
			),
			array(
				'id'      => 'box_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Box Background Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content' => 'background-color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout2:before' => 'background-color: {{VALUE}} !important',
				),
			),
			array(
				'id'      => 'title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Title', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content .title a' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout2 .item-content .title a' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content .title a, {{WRAPPER}} .portfolio-box.portfolio-layout2 .item-content .title a',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .portfolio-box.portfolio-layout2 .item-content .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .portfolio-box.portfolio-layout2 .item-content .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'id'      => 'title_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Title Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Hover Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content .title a:hover' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout2 .item-content .title a:hover' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'id'      => 'sub_title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Sub Title', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'sub_title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content .sub-title a' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout2 .item-content .sub-title a' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'sub_title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content .sub-title a, {{WRAPPER}} .portfolio-box.portfolio-layout2 .item-content .sub-title a',
			),
			array(
				'id'      => 'sub_title_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'sub_title_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content .sub-title a:hover' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout2 .item-content .sub-title a:hover' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode' => 'section_end',
			),
			
			
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ($data['style']) {
			case 'style2':
				$template = 'view-2';
			break;
			default:
				$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}