<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;
use radiustheme\woddingat\inc\Helper;

use Elementor\Utils;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Image_Size;

if ( ! defined( 'ABSPATH' ) ) exit;

class Portfolio extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Portfolio', 'woddingat-core' );
		$this->rt_base = 'rt-portfolio';
		$this->rt_translate = array(
			'cols'  => array(
				'12' => esc_html__( '1 Col', 'woddingat-core' ),
				'6'  => esc_html__( '2 Col', 'woddingat-core' ),
				'4'  => esc_html__( '3 Col', 'woddingat-core' ),
				'3'  => esc_html__( '4 Col', 'woddingat-core' ),
				'2'  => esc_html__( '6 Col', 'woddingat-core' ),
			),
		);
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$cpt               = WODDINGAT_CORE_CPT;
        $terms             = get_terms(array('taxonomy' => "{$cpt}_portfolio_category", 'fields' => 'id=>name'));
        $category_dropdown = array('0' => esc_html__('All Categories', 'woddingat-core'));

        foreach ($terms as $id => $name) {
            $category_dropdown[$id] = $name;
        }

		$fields = array(
			array(
				'id'      => 'sec_rt_portfolio',
				'mode'    => 'section_start',
				'label'   => esc_html__( 'Portfolio', 'woddingat-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'woddingat-core' ),
				'options' => array(
					'style1' => esc_html__( 'Layout 1', 'woddingat-core' ),
					'style2' => esc_html__( 'Layout 2', 'woddingat-core' ),
					'style3' => esc_html__( 'Layout 3', 'woddingat-core' ),
					'style4' => esc_html__( 'Layout 4', 'woddingat-core' ),
					'style5' => esc_html__( 'Layout 5', 'woddingat-core' ),
					'style6' => esc_html__( 'Layout 6', 'woddingat-core' ),
				),
				'default' => 'style1',
				'label_block' => true,
			),
			// Post per page
			array(
				'id'      => 'number',
				'label'   =>esc_html__( 'Total number of post', 'woddingat-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 12,
				'description' =>esc_html__( 'Write -1 to show all', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'id'      => 'orderby',
				'label'   => esc_html__( 'Order By', 'woddingat-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => array(
					'date'        => esc_html__( 'Date (Recents comes first)', 'woddingat-core' ),
					'title'       => esc_html__( 'Title', 'woddingat-core' ),
				),
				'default' => 'date',
				'label_block' => true,
			),
			array(
				'id'      => 'order',
				'label'   => esc_html__( 'Order', 'woddingat-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => array(
					'ASC' => __( 'Ascending Order', 'woddingat-core' ),
					'DESC' => __( 'Descending', 'woddingat-core' ),
				),
				'default' => 'DESC',
				'label_block' => true,
			),
			array(
                'type'     => Controls_Manager::SELECT2,
                'id'       => 'category_list',
                'label'    => esc_html__('Categories', 'woddingat-core'),
                'options'  => $category_dropdown,
                'default'  => '0',
                'multiple' => true,
            ),
			array(
				'type'    => Controls_Manager::SWITCHER,
				'id'      => 'cat_showhide',
				'label'   => esc_html__( 'Category', 'woddingat-core' ),
				'label_on'    => esc_html__( 'Show', 'woddingat-core' ),
				'label_off'   => esc_html__( 'Hide', 'woddingat-core' ),
				'default'     => 'yes',
			),
			array(
				'id'      => 'boxstyle',
				'label'   => esc_html__( 'Box Style', 'woddingat-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => array(
					'style1'        => esc_html__( 'Style 1', 'woddingat-core' ),
					'style2'        => esc_html__( 'Style 2', 'woddingat-core' ),
					'style3'        => esc_html__( 'Style 3', 'woddingat-core' ),
				),
				'default' => 'style1',
				'label_block' => true,
				'condition' => array( 'style' => array( 'style5' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			// Responsive Columns
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_responsive',
				'label'   => esc_html__( 'Number of Responsive Columns', 'woddingat-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_lg',
				'label'   => esc_html__( 'Desktops: > 1199px', 'woddingat-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '4',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_md',
				'label'   => esc_html__( 'Desktops: > 991px', 'woddingat-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '4',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_sm',
				'label'   => esc_html__( 'Tablets: > 767px', 'woddingat-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '6',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_xs',
				'label'   => esc_html__( 'Phones: < 768px', 'woddingat-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '12',
			),
			array(
				'type'    => Controls_Manager::SWITCHER,
				'id'      => 'col_five',
				'label'   => esc_html__( 'Five Column', 'woddingat-core' ),
				'label_on'    => esc_html__( 'Show', 'woddingat-core' ),
				'label_off'   => esc_html__( 'Hide', 'woddingat-core' ),
				'default'     => 'no',
				'condition' => array( 'style' => array( 'style5' ) ),
			),
			array(
				'mode' => 'section_end',
			),			
			// Style
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'woddingat-core' ),
			),
			array(
				'id'      => 'title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Normal', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .portfolio-box.portfolio-layout3 .item-content .title a' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content .title a' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout2 .item-content .title a' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout4 .item-content .title a' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout5 .item-content .title a' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .portfolio-box.portfolio-layout3 .item-content .title a, {{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content .title a, {{WRAPPER}} .portfolio-box.portfolio-layout2 .item-content .title a, {{WRAPPER}} .portfolio-box.portfolio-layout4 .item-content .title a, {{WRAPPER}} .portfolio-box.portfolio-layout5 .item-content .title a',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .portfolio-box.portfolio-layout3 .item-content .title a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content .title a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .portfolio-box.portfolio-layout2 .item-content .title a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .portfolio-box.portfolio-layout4 .item-content .title a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .portfolio-box.portfolio-layout2.style-2 .item-content .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .portfolio-box.portfolio-layout5 .item-content .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .portfolio-box.portfolio-layout3 .item-content .title a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	                '{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content .title a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	                '{{WRAPPER}} .portfolio-box.portfolio-layout2 .item-content .title a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	                '{{WRAPPER}} .portfolio-box.portfolio-layout4 .item-content .title a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	                '{{WRAPPER}} .portfolio-box.portfolio-layout2.style-2 .item-content .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	                '{{WRAPPER}} .portfolio-box.portfolio-layout5 .item-content .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	            ),
	            'separator' => 'before',
	        ),
			array(
				'id'      => 'title_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .portfolio-box.portfolio-layout3 .item-content .title a:hover' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content .title a:hover' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout2 .item-content .title a:hover' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout4 .item-content .title a:hover' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout5 .item-content .title a:hover' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'sub_title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Sub Title', 'woddingat-core' ),
			),
			array(
				'id'      => 'sub_title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Normal', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'sub_title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .portfolio-box.portfolio-layout3 .item-content .sub-title a' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content .sub-title a' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout2.style-2 .item-content .sub-title a' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout4 .item-content .sub-title a' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout5 .item-content .sub-title a' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'sub_title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .portfolio-box.portfolio-layout3 .item-content .sub-title a, {{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content .sub-title a, {{WRAPPER}} .portfolio-box.portfolio-layout2.style-2 .item-content .sub-title a, {{WRAPPER}} .portfolio-box.portfolio-layout4 .item-content .sub-title a, {{WRAPPER}} .portfolio-box.portfolio-layout5 .item-content .sub-title a',
			),
			array(
				'id'      => 'sub_title_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'sub_title_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .portfolio-box.portfolio-layout3 .item-content .sub-title a:hover' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content .sub-title a:hover' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout2.style-2 .item-content .sub-title a:hover' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout4 .item-content .sub-title a:hover' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout5 .item-content .sub-title a:hover' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode' => 'section_end',
			),
			// Box Style
			array(
				'id'      => 'box_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Box Style', 'woddingat-core' ),
			),
			array(
				'id'      => 'box_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .portfolio-box.portfolio-layout3 .item-content' => 'background-color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout1 .item-content' => 'background-color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout2:before' => 'background-color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout4 .item-content' => 'background-color: {{VALUE}} !important',
					'{{WRAPPER}} .portfolio-box.portfolio-layout5 .item-content' => 'background-color: {{VALUE}} !important',
				),
			),
			array(
				'mode' => 'section_end',
			),
			
			
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ($data['style']) {
			case 'style6':
				$template = 'view-6';
			break;
			case 'style5':
				$template = 'view-5';
			break;
			case 'style4':
				$template = 'view-4';
			break;
			case 'style3':
				$template = 'view-3';
			break;
			case 'style2':
				$template = 'view-2';
			break;
			default:
				$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}