<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use radiustheme\woddingat\inc\RDTheme;
use radiustheme\woddingat\inc\Helper;

if ( ! defined( 'ABSPATH' ) ) exit;

class Post extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Posts', 'woddingat-core' );
		$this->rt_base = 'rt-post';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){

		$fields = array(
			array(
				'id'      => 'sec_rt_post',
				'mode'    => 'section_start',
				'label'   => esc_html__( 'Posts', 'woddingat-core' ),
			),
			// Post per page
			array(
				'id'      => 'number',
				'label'   =>esc_html__( 'Total number of post', 'woddingat-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'description' =>esc_html__( 'Write -1 to show all', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::NUMBER,
				'id'      => 'title_length',
				'label'   => esc_html__( 'Title Length', 'woddingat-core' ),
				'default' => 13,
				'description' => esc_html__( 'Maximum number of words', 'woddingat-core' ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'post_cat',
				'label'       => esc_html__( 'Category', 'woddingat-core' ),
				'label_on'    => esc_html__( 'On', 'woddingat-core' ),
				'label_off'   => esc_html__( 'Off', 'woddingat-core' ),
				'return_value' => 'on',
				'default' 	   => 'on',
				'description' => esc_html__( 'Enable or disable post category. Default: On', 'woddingat-core' ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'post_date',
				'label'       => esc_html__( 'Date', 'woddingat-core' ),
				'label_on'    => esc_html__( 'On', 'woddingat-core' ),
				'label_off'   => esc_html__( 'Off', 'woddingat-core' ),
				'return_value' => 'on',
				'default' 	   => 'on',
				'description' => esc_html__( 'Enable or disable post date. Default: On', 'woddingat-core' ),
			),
			array(
				'id'      => 'cols',
				'label'   => esc_html__( 'Grid Columns', 'woddingat-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => $this->rt_grid_options(),
				'default' => '4',
				'label_block' => true,
			),
			array(
				'mode' => 'section_end',
			),
			// Style
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'woddingat-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .blog-box .content-box .title a' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .blog-box .content-box .title a',
			),
			array(
				'id'      => 'title_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Hover Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .blog-box .content-box .title a:hover' => 'color: {{VALUE}} !important', 
				),
			),
			// Meta
			array(
				'id'      => 'meta_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Meta Style', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'meta_icon_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Icon Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .blog-box .content-box .entry-meta li i' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'id'      => 'meta_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .blog-box .content-box .entry-meta li' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .blog-box .content-box .entry-meta li span' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .blog-box .content-box .entry-meta li a' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'meta_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .blog-box .content-box .entry-meta li, {{WRAPPER}} .blog-box .content-box .entry-meta li span, {{WRAPPER}} .blog-box .content-box .entry-meta li a',
			),
			array(
				'id'      => 'meta_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Meta Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'meta_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .blog-box .content-box .entry-meta li a:hover' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$template = 'view';

		return $this->rt_template( $template, $data );
	}
}
