<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;

use Elementor\Utils;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Image_Size;

if ( ! defined( 'ABSPATH' ) ) exit;

class Services extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Services', 'woddingat-core' );
		$this->rt_base = 'rt-service';
		$this->rt_translate = array(
			'cols'  => array(
				'12' => esc_html__( '1 Col', 'woddingat-core' ),
				'6'  => esc_html__( '2 Col', 'woddingat-core' ),
				'4'  => esc_html__( '3 Col', 'woddingat-core' ),
				'3'  => esc_html__( '4 Col', 'woddingat-core' ),
				'2'  => esc_html__( '6 Col', 'woddingat-core' ),
			),
		);
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_rt_service',
				'mode'    => 'section_start',
				'label'   => esc_html__( 'Services', 'woddingat-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'woddingat-core' ),
				'options' => array(
					'style1' => esc_html__( 'Layout 1', 'woddingat-core' ),
					'style2' => esc_html__( 'Layout 2', 'woddingat-core' ),
				),
				'default' => 'style1',
				'label_block' => true,
			),
			// Post per page
			array(
				'id'      => 'number',
				'label'   =>esc_html__( 'Total number of post', 'woddingat-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 4,
				'description' =>esc_html__( 'Write -1 to show all', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'id'      => 'excerpt',
				'label'   =>esc_html__( 'Content excerpt number', 'woddingat-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => '16',
				'label_block' => true,
			),
			array(
				'id'      => 'orderby',
				'label'   => esc_html__( 'Order By', 'woddingat-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => array(
					'date'        => esc_html__( 'Date (Recents comes first)', 'woddingat-core' ),
					'title'       => esc_html__( 'Title', 'woddingat-core' ),
				),
				'default' => 'date',
				'label_block' => true,
			),
			array(
				'id'      => 'order',
				'label'   => esc_html__( 'Order', 'woddingat-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => array(
					'ASC' => __( 'Ascending Order', 'woddingat-core' ),
					'DESC' => __( 'Descending', 'woddingat-core' ),
				),
				'default' => 'DESC',
				'label_block' => true,
			),
			array(
                'type'        => Controls_Manager::SWITCHER,
                'id'          => 'category',
                'label'       => esc_html__('Category', 'woddingat-core'),
                'label_on'    => esc_html__('On', 'woddingat-core'),
                'label_off'   => esc_html__('Off', 'woddingat-core'),
                'default'     => 'yes',
                'description' => esc_html__('Categorys. Default: On', 'woddingat-core'),
            ),
            array(
                'type'        => Controls_Manager::SWITCHER,
                'id'          => 'button_link',
                'label'       => esc_html__('Button Link', 'woddingat-core'),
                'label_on'    => esc_html__('On', 'woddingat-core'),
                'label_off'   => esc_html__('Off', 'woddingat-core'),
                'default'     => 'yes',
                'description' => esc_html__('Button. Default: On', 'woddingat-core'),
            ),
			array(
				'mode' => 'section_end',
			),
			// Responsive Columns
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_responsive',
				'label'   => esc_html__( 'Number of Responsive Columns', 'woddingat-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_lg',
				'label'   => esc_html__( 'Desktops: > 1199px', 'woddingat-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '4',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_md',
				'label'   => esc_html__( 'Desktops: > 991px', 'woddingat-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '4',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_sm',
				'label'   => esc_html__( 'Tablets: > 767px', 'woddingat-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '6',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_xs',
				'label'   => esc_html__( 'Phones: < 768px', 'woddingat-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '12',
			),
			array(
				'mode' => 'section_end',
			),	
			// Style
			array(
				'id'      => 'box_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Box Style', 'woddingat-core' ),
			),
			array(
				'id'      => 'box_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Normal', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
			    'type'    	=> Controls_Manager::COLOR,
			    'id'      	=> 'box_bg_color',
			    'label'   	=> __( 'Background Color', 'woddingat-core' ),
			    'default' 	=> '',                       
			    'selectors' => array(
			        '{{WRAPPER}} .service-box-layout1' => 'background-color: {{VALUE}}',      
			        '{{WRAPPER}} .service-box-layout2' => 'background-color: {{VALUE}}',      
			        ),
			),
			array(
			    'type'    	=> Controls_Manager::COLOR,
			    'id'      	=> 'box_border_color',
			    'label'   	=> __( 'Border Color', 'woddingat-core' ),
			    'default' 	=> '',                       
			    'selectors' => array(
			        '{{WRAPPER}} .service-box-layout1' => 'border-color: {{VALUE}}',      
			        '{{WRAPPER}} .service-box-layout2' => 'border-color: {{VALUE}}',      
			        ),
			    'condition' => array( 'style' => array( 'style1' ) ),
			),
			array(
				'id'      => 'box_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
			    'type'    	=> Controls_Manager::COLOR,
			    'id'      	=> 'box_h_bg_color',
			    'label'   	=> __( 'Background Color', 'woddingat-core' ),
			    'default' 	=> '',                       
			    'selectors' => array(
			        '{{WRAPPER}} .service-box-layout1:hover' => 'background-color: {{VALUE}}',      
			        '{{WRAPPER}} .service-box-layout2:hover' => 'background-color: {{VALUE}}',      
			        ),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'icon_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Icon', 'woddingat-core' ),
			),
			array(
				'id'      => 'icon_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Icon', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'icon_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service-box-layout1 .icon-box' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .service-box-layout2 .icon-box' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'name'     => 'icon_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .service-box-layout1 .icon-box, {{WRAPPER}} .service-box-layout2 .icon-box',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'woddingat-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service-box-layout1 .title' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .service-box-layout2 .title' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .service-box-layout1 .title, {{WRAPPER}} .service-box-layout2 .title',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .service-box-layout1 .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .service-box-layout2 .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .service-box-layout1 .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .service-box-layout2 .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'sub_title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Sub Title', 'woddingat-core' ),
				'condition' => array( 'style' => array( 'style1' ) ),
			),
			array(
				'id'      => 'sub_title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service-box-layout1 .sub-title' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'sub_title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .service-box-layout1 .sub-title',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'sub_title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .service-box-layout1 .sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'sub_title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .service-box-layout1 .sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'desc_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Description', 'woddingat-core' ),
			),
			array(
				'id'      => 'text_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service-box-layout1 .description' => 'color: {{VALUE}} !important', 
					'{{WRAPPER}} .service-box-layout2 .description' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'text_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .service-box-layout1 .description, {{WRAPPER}} .service-box-layout2 .description',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'btn_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Button', 'woddingat-core' ),
				'condition' => array( 'style' => array( 'style1' ) ),
			),
			array(
				'id'      => 'btn_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Normal', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'btn_text_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service-box-layout1 .btn-text.style-4' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'button_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .service-box-layout1 .btn-text.style-4',
			), 
			array(
				'id'      => 'btn_hover_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'btn_text_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service-box-layout1 .btn-text.style-4:hover' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode' => 'section_end',
			),
			
			
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ($data['style']) {
			case 'style2':
				$template = 'view-2';
			break;
			default:
				$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}