<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit;

class Slider extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = esc_html__( 'Slider', 'woddingat-core' );
		$this->rt_base = 'rt-slider';	
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'banner_image', [
				'type' 		  => Controls_Manager::MEDIA,
				'label'       => esc_html__( 'Banner Image', 'woddingat-core' ),
				'description' => esc_html__( 'Recommended image size is 1920px X 800px', 'woddingat-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'banner_image2', [
				'type' 		  => Controls_Manager::MEDIA,
				'label'       => esc_html__( 'Banner Image 2', 'woddingat-core' ),
				'description' => esc_html__( 'Recommended image size is 145px X 72px', 'woddingat-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'banner_title', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Title', 'woddingat-core' ),
				'default'     => esc_html__( 'We Are Engaged', 'woddingat-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'banner_sub_title', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Sub Title', 'woddingat-core' ),
				'default'     => esc_html__( 'JONN & JANE SAID YES!', 'woddingat-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'banner_text', [
				'type' 		  => Controls_Manager::TEXTAREA,
				'label'       => esc_html__( 'Banner Text', 'woddingat-core' ),
				'default'     => esc_html__( 'Grursus mal suada faci lisis Lorem ipsum dolarorit more a ametion consectetur elit.', 'woddingat-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'button_text', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Button Text', 'woddingat-core' ),
				'default'     => esc_html__( 'READ MORE', 'woddingat-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'button_url', [
				'type' 		  => Controls_Manager::URL,
				'label'       => esc_html__( 'Button URL', 'woddingat-core' ),
				'placeholder' => esc_url('https://your-link.com' ),
				'label_block' => true,
			]
		);

		$fields = array(
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_general',
				'label'   => __( 'General', 'woddingat-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'woddingat-core' ),
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'woddingat-core' ),
					'style2' => esc_html__( 'Style 2', 'woddingat-core' ),
				),
				'default' => 'style1',
				'label_block' => true,
			),
			array (
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'banner_list',
				'label'   => esc_html__( 'Add as many slide as you want', 'woddingat-core' ),
				'fields'  => $repeater->get_controls(),
		       'default'  => [
					[
						'banner_title'     => __( 'We Are Engaged', 'woddingat-core' ),
						'banner_sub_title' => __( 'JONN & JANE SAID YES!', 'woddingat-core' ),
						'banner_text'      => __( 'Grursus mal suada faci lisis Lorem ipsum dolarorit more a ametion consectetur elit.', 'woddingat-core' ),
						'button_text'      => __( 'READ MORE', 'woddingat-core' ),
						'button_url'       => '#',
					],
					[
						'banner_title'     => __( 'We Are Engaged', 'woddingat-core' ),
						'banner_sub_title' => __( 'JONN & JANE SAID YES!', 'woddingat-core' ),
						'banner_text'      => __( 'Grursus mal suada faci lisis Lorem ipsum dolarorit more a ametion consectetur elit.', 'woddingat-core' ),
						'button_text'      => __( 'READ MORE', 'woddingat-core' ),
						'button_url'       => '#',
					],
					[
						'banner_title'     => __( 'We Are Engaged', 'woddingat-core' ),
						'banner_sub_title' => __( 'JONN & JANE SAID YES!', 'woddingat-core' ),
						'banner_text'      => __( 'Grursus mal suada faci lisis Lorem ipsum dolarorit more a ametion consectetur elit.', 'woddingat-core' ),
						'button_text'      => __( 'READ MORE', 'woddingat-core' ),
						'button_url'       => '#',
					],
				],
			),
			array(
				'type'    => Controls_Manager::SWITCHER,
				'id'      => 'show_social',
				'label'   => esc_html__( 'Socials', 'woddingat-core' ),
				'label_on'    => esc_html__( 'Show', 'woddingat-core' ),
				'label_off'   => esc_html__( 'Hide', 'woddingat-core' ),
				'default'     => 'yes',
				'condition'   => array( 'style' => array( 'style2' ) ),	
			),
			array(
				'type'    => Controls_Manager::SWITCHER,
				'id'      => 'show_arrow',
				'label'   => esc_html__( 'Arrow', 'woddingat-core' ),
				'label_on'    => esc_html__( 'Show', 'woddingat-core' ),
				'label_off'   => esc_html__( 'Hide', 'woddingat-core' ),
				'default'     => 'yes',
				'condition'   => array( 'style' => array( 'style2' ) ),	
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'woddingat-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .main-banner-layout1 .slide .banner-big-text' => 'color: {{VALUE}} !important', 
					'{{WRAPPER}} .main-banner-layout2 .slide .banner-big-text' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .main-banner-layout1 .slide .banner-big-text, {{WRAPPER}} .main-banner-layout2 .slide .banner-big-text',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .main-banner-layout1 .slide .banner-big-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .main-banner-layout2 .slide .banner-big-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .main-banner-layout1 .slide .banner-big-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	                '{{WRAPPER}} .main-banner-layout2 .slide .banner-big-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'sub_title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Sub Title', 'woddingat-core' ),
			),
			array(
				'id'      => 'sub_title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .main-banner-layout1 .slide .banner-sub-title' => 'color: {{VALUE}} !important', 
					'{{WRAPPER}} .main-banner-layout2 .slide .banner-sub-title' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'sub_title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .main-banner-layout1 .slide .banner-sub-title, {{WRAPPER}} .main-banner-layout2 .slide .banner-sub-title',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'sub_title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .main-banner-layout1 .slide .banner-sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .main-banner-layout2 .slide .banner-sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'sub_title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .main-banner-layout1 .slide .banner-sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	                '{{WRAPPER}} .main-banner-layout2 .slide .banner-sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'content_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Content', 'woddingat-core' ),
			),
			array(
				'id'      => 'content_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .main-banner-layout1 .slide .banner-paragraph' => 'color: {{VALUE}} !important', 
					'{{WRAPPER}} .main-banner-layout2 .slide .banner-paragraph' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'content_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .main-banner-layout1 .slide .banner-paragraph, {{WRAPPER}} .main-banner-layout2 .slide .banner-paragraph',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'button_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Button', 'woddingat-core' ),
			),
			array(
				'id'      => 'button_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .main-banner-layout1 .slide .btn-fill' => 'color: {{VALUE}} !important', 
					'{{WRAPPER}} .main-banner-layout2 .slide .btn-fill' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'button_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .main-banner-layout1 .slide .btn-fill, {{WRAPPER}} .main-banner-layout2 .slide .btn-fill',
			),
			array(
				'id'      => 'button_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .main-banner-layout1 .slide .btn-fill' => 'background-color: {{VALUE}} !important', 
					'{{WRAPPER}} .main-banner-layout2 .slide .btn-fill' => 'background-color: {{VALUE}} !important', 
				),
			),
			array(
				'name'       => 'btn_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .main-banner-layout1 .slide .btn-fill > span, {{WRAPPER}} .main-banner-layout2 .slide .btn-fill > span',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'nav_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Nav', 'woddingat-core' ),
				'condition'   => array( 'style' => array( 'style1' ) ),
			),
			array(
				'id'      => 'nav_normal_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Normal', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'nav_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .main-banner-layout1 .nivo-directionNav .nivo-prevNav, .main-banner-layout1 .nivo-directionNav .nivo-nextNav' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'nav_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .main-banner-layout1 .nivo-directionNav .nivo-prevNav, .main-banner-layout1 .nivo-directionNav .nivo-nextNav',
			),
			array(
				'id'      => 'nav_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .main-banner-layout1 .nivo-directionNav .nivo-prevNav, .main-banner-layout1 .nivo-directionNav .nivo-nextNav' => 'background-color: {{VALUE}} !important', 
				),
			),
			array(
				'id'      => 'nav_hover_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'nav_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .main-banner-layout1 .nivo-directionNav .nivo-prevNav:hover, .main-banner-layout1 .nivo-directionNav .nivo-nextNav:hover' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'id'      => 'nav_hbg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .main-banner-layout1 .nivo-directionNav .nivo-prevNav:hover, .main-banner-layout1 .nivo-directionNav .nivo-nextNav:hover' => 'background-color: {{VALUE}} !important', 
				),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'social_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Social', 'woddingat-core' ),
				'condition'   => array( 'style' => array( 'style2' ) ),
			),
			array(
				'id'      => 'social_normal_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Normal', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'icon_normal_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .main-banner-layout2 .social li a' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'icon_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .main-banner-layout2 .social li a',
			),
			array(
				'id'      => 'icon_hover_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'icon_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .main-banner-layout2 .social li a:hover' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'dot_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Dot', 'woddingat-core' ),
				'condition'   => array( 'style' => array( 'style2' ) ),
			),
			array(
				'id'      => 'dot_normal_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Normal', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'dot_normal_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .main-banner-layout2 .nivo-controlNav .nivo-control:before' => 'border-color: {{VALUE}} !important', 
				),
			),
			array(
				'id'      => 'dot_active_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Active', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'dot_active_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .main-banner-layout2 .nivo-controlNav .nivo-control.active:before' => 'background-color: {{VALUE}} !important', 
				),
			),
			array(
				'id'      => 'dot_active_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .main-banner-layout2 .nivo-controlNav .nivo-control.active' => 'border-color: {{VALUE}} !important', 
				),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}
	protected function render() {
		$data = $this->get_settings();

		switch ($data['style']) {
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}
		return $this->rt_template( $template, $data );		
	}
}