<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit;

class Split_Slider extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = esc_html__( 'Split Slider', 'woddingat-core' );
		$this->rt_base = 'rt-split-slider';	
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'banner_image', [
				'type' 		  => Controls_Manager::MEDIA,
				'label'       => esc_html__( 'Banner Image', 'woddingat-core' ),
				'description' => esc_html__( 'Recommended image size full', 'woddingat-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'banner_image2', [
				'type' 		  => Controls_Manager::MEDIA,
				'label'       => esc_html__( 'Banner Image 2', 'woddingat-core' ),
				'description' => esc_html__( 'Recommended image size full', 'woddingat-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'banner_title', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Title', 'woddingat-core' ),
				'default'     => esc_html__( 'WEDDING DAYS', 'woddingat-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'banner_text', [
				'type' 		  => Controls_Manager::TEXTAREA,
				'label'       => esc_html__( 'Banner Text', 'woddingat-core' ),
				'default'     => esc_html__( 'Grursus mal suada faci lisis consectetur elit.', 'woddingat-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'banner_gallery', [
				'type' 		  => Controls_Manager::GALLERY,
				'label'       => esc_html__( 'Gallery', 'woddingat-core' ),
				'label_block' => true,
			]
		);

		$fields = array(
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_general',
				'label'   => __( 'General', 'woddingat-core' ),
			),
			array (
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'slider_list',
				'label'   => esc_html__( 'Add as many slide as you want', 'woddingat-core' ),
				'fields'  => $repeater->get_controls(),
		       'default'  => [
					[
						'banner_title'     => __( 'WEDDING DAYS', 'woddingat-core' ),
						'banner_text'      => __( 'Grursus mal suada faci lisis consectetur elit.', 'woddingat-core' ),
					],
					[
						'banner_title'     => __( 'LOVE FOREVER', 'woddingat-core' ),
						'banner_text'      => __( 'Grursus mal suada faci lisis consectetur elit.', 'woddingat-core' ),
					],
					[
						'banner_title'     => __( 'WEDDING TIME', 'woddingat-core' ),
						'banner_text'      => __( 'Grursus mal suada faci lisis consectetur elit.', 'woddingat-core' ),
					],
					[
						'banner_title'     => __( 'WEDDING TIME', 'woddingat-core' ),
						'banner_text'      => __( 'Grursus mal suada faci lisis consectetur elit.', 'woddingat-core' ),
					],
				],
			),
			array(
				'type'    => Controls_Manager::SWITCHER,
				'id'      => 'show_social',
				'label'   => esc_html__( 'Socials', 'woddingat-core' ),
				'label_on'    => esc_html__( 'Show', 'woddingat-core' ),
				'label_off'   => esc_html__( 'Hide', 'woddingat-core' ),
				'default'     => 'yes',	
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'woddingat-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .pagepiling-layout .left-box .content-box .title' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .pagepiling-layout .left-box .content-box .title',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .pagepiling-layout .left-box .content-box .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                 
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .pagepiling-layout .left-box .content-box .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'content_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Content', 'woddingat-core' ),
			),
			array(
				'id'      => 'content_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .pagepiling-layout .left-box .content-box .sub-title' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'content_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .pagepiling-layout .left-box .content-box .sub-title',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'social_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Social', 'woddingat-core' ),
			),
			array(
				'id'      => 'social_normal_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Normal', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'icon_normal_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .pagepiling-layout .left-box .social li a' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'icon_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .pagepiling-layout .left-box .social li a',
			),
			array(
				'id'      => 'icon_hover_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'icon_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .pagepiling-layout .left-box .social li a:hover' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}
	protected function render() {
		$data = $this->get_settings();

		$template = 'view';

		return $this->rt_template( $template, $data );		
	}
}