<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Story_Box extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = esc_html__( 'Story Box', 'woddingat-core' );
		$this->rt_base = 'rt-story-box';	
		parent::__construct( $data, $args );
	}

	public function rt_fields(){

		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'his_icon', [
				'type' 		  => Controls_Manager::ICONS,
				'label'       => esc_html__( 'Icon', 'woddingat-core' ),
				'description' => esc_html__( 'Select icon', 'woddingat-core' ),
				'default'     => [
				      'value'   => 'flaticon-negotiation',
				      'library' => 'fa-solid',
				  	],
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'his_title', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Title', 'woddingat-core' ),
				'default'     => esc_html__( 'First Time We Meet', 'woddingat-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'his_date', [
				'type' 		  => Controls_Manager::DATE_TIME,
				'label'       => esc_html__( 'Date', 'woddingat-core' ),
				'description' => esc_html__('Set date and time', 'woddingat-core'),
				'default'     => '2020-06-20',
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'his_text', [
				'type' 		  => Controls_Manager::TEXTAREA,
				'label'   => esc_html__( 'Content', 'woddingat-core' ),
				'default' => esc_html__( 'Grursus mal suada faci lisis Lorem ipsum dolarorit more ametion consectetur elit. Vesti at bulum nec ipsum.', 'woddingat-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'his_img', [
				'type' 		  => Controls_Manager::MEDIA,
				'label'   => esc_html__( 'Image', 'woddingat-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'woddingat-core' ),
			]
		);

		$fields = array(
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_general',
				'label'   => __( 'General', 'woddingat-core' ),
			),
			array(
				'id'      => 'rightbox_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Right Box', 'woddingat-core' ),
				'separator' => 'before',
			),
			array (
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'history_list',
				'label'   => esc_html__( 'Add as many history as you want', 'woddingat-core' ),
				'fields'  => $repeater->get_controls(),
		       	'default' => [
					[
						'his_icon'  => 'flaticon-negotiation',
						'his_title' => __( 'First Time We Meet', 'woddingat-core' ),
						'his_date'  => __( '2020-06-20', 'woddingat-core' ),
						'his_text'  => __( 'Grursus mal suada faci lisis Lorem ipsum dolarorit more ametion consectetur elit. Vesti at bulum nec ipsum.', 'woddingat-core' ),
					],
					[
						'his_icon'  => 'flaticon-love',
						'his_title' => __( 'We Fall in Love Each Other', 'woddingat-core' ),
						'his_date'  => __( '2020-06-23', 'woddingat-core' ),
						'his_text'  => __( 'Grursus mal suada faci lisis Lorem ipsum dolarorit more ametion consectetur elit. Vesti at bulum nec ipsum.', 'woddingat-core' ),
					],
					[
						'his_icon'  => 'flaticon-wedding-rings',
						'his_title' => __( 'He asked?..She said Yes', 'woddingat-core' ),
						'his_date'  => __( '2020-06-25', 'woddingat-core' ),
						'his_text'  => __( 'Grursus mal suada faci lisis Lorem ipsum dolarorit more ametion consectetur elit. Vesti at bulum nec ipsum.', 'woddingat-core' ),
					],
					[
						'his_icon'  => 'flaticon-wedding',
						'his_title' => __( 'The Wedding Day!', 'woddingat-core' ),
						'his_date'  => __( '2020-06-29', 'woddingat-core' ),
						'his_text'  => __( 'Grursus mal suada faci lisis Lorem ipsum dolarorit more ametion consectetur elit. Vesti at bulum nec ipsum.', 'woddingat-core' ),
					],
				],
			),
			array(
				'id'      => 'leftbox_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Left Box', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'image1',
				'label'   => esc_html__( 'Image 1', 'woddingat-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'woddingat-core' ),
			),
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'signature_img',
				'label'   => esc_html__( 'Signature Image', 'woddingat-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'woddingat-core' ),
			),
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'image2',
				'label'   => esc_html__( 'Image 2', 'woddingat-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'woddingat-core' ),
			),
			array(
				'id'      => 'title1',
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title 1', 'woddingat-core' ),
				'default' => esc_html__( 'mr', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'id'      => 'title2',
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title 2', 'woddingat-core' ),
				'default' => esc_html__( 'mrs', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'left_box_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Left Box', 'woddingat-core' ),
			),
			array(
				'name'       => 'box_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Box Border', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .story-left-box',
			),
			array(
				'id'      => 'leftbox_title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Title', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .story-left-box ul li span' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .story-left-box ul li span',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .story-left-box ul li span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .story-left-box ul li span' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	            ),
	            'separator' => 'before',
	        ),
	        array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'right_box_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Right Box', 'woddingat-core' ),
			),
			array(
				'id'      => 'rightbox_line_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Line', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'line_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Line Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .straight-line:before' => 'background-color: {{VALUE}} !important' ),
			),
			array(
				'id'      => 'line_dotbg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Dot Background', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .straight-line .start-end-point:after' => 'background-color: {{VALUE}} !important', 
					'{{WRAPPER}} .straight-line .start-end-point:before' => 'background-color: {{VALUE}} !important', 
				),
			),
			array(
				'id'      => 'line_dotborder_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Dot Border', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .straight-line .start-end-point:after' => 'border-color: {{VALUE}} !important', 
					'{{WRAPPER}} .straight-line .start-end-point:before' => 'border-color: {{VALUE}} !important', 
				),
			),
			array(
				'id'      => 'iconbox_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Icon Box Normal', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'icon_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .story-box-layout1 .icon-box' => 'color: {{VALUE}} !important' ),
			),
			array(
				'id'      => 'icon_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .story-box-layout1 .icon-box' => 'background-color: {{VALUE}} !important' ),
			),
			array(
				'id'      => 'icon_border_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .story-box-layout1 .icon-box' => 'border-color: {{VALUE}} !important' ),
			),
			array(
				'id'      => 'iconbox_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Icon Box Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'iconh_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .story-box-layout1:hover .icon-box' => 'color: {{VALUE}} !important' ),
			),
			array(
				'id'      => 'icon_bgh_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .story-box-layout1:hover .icon-box' => 'background-color: {{VALUE}} !important' ),
			),
			array(
				'id'      => 'icon_borderh_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .story-box-layout1:hover .icon-box' => 'border-color: {{VALUE}} !important' ),
			),
			array(
				'id'      => 'rightbox_con_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Right Box Content', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'rbox_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .story-box-layout1' => 'background-color: {{VALUE}} !important', 
					'{{WRAPPER}} .story-box-layout1:before' => 'border-right-color: {{VALUE}} !important', 
				),
			),
			array(
				'id'      => 'rbox_bgh_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Hover Background', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .story-box-layout1:hover' => 'background-color: {{VALUE}} !important', 
					'{{WRAPPER}} .story-box-layout1:hover:before' => 'border-right-color: {{VALUE}} !important', 
				),
			),
			array(
				'id'      => 'rbox_title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Title Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .story-box-layout1 .title' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'rbox_title_typo',
				'label'    => esc_html__( 'Title Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .story-box-layout1 .title',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'rbox_title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Title Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .story-box-layout1 .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'rbox_title_margin',
	            'label'   => esc_html__( 'Title Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .story-box-layout1 .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
	        array(
				'id'      => 'rbox_date_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Date Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .story-box-layout1 .date' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'rbox_date_typo',
				'label'    => esc_html__( 'Date Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .story-box-layout1 .date',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'rbox_date_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Date Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .story-box-layout1 .date' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'rbox_date_margin',
	            'label'   => esc_html__( 'Date Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .story-box-layout1 .date' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
	        array(
				'id'      => 'rbox_content_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Content Color', 'woddingat-core' ),
				'selectors' => array( '{{WRAPPER}} .story-box-layout1 .description' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'rbox_content_typo',
				'label'    => esc_html__( 'Content Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .story-box-layout1 .description',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'rbox_content_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Content Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .story-box-layout1 .description' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'rbox_content_margin',
	            'label'   => esc_html__( 'Content Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .story-box-layout1 .description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}
	protected function render() {
		$data 	  = $this->get_settings();

		$template = 'view';
		
		return $this->rt_template( $template, $data );		
	}
}