<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;
use radiustheme\woddingat\inc\Helper;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Team_Tab extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Team Tab', 'woddingat-core' );
		$this->rt_base = 'rt-team-tab';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){

		$cpt               = WODDINGAT_CORE_CPT;
        $terms             = get_terms(array('taxonomy' => "{$cpt}_team_category", 'fields' => 'id=>name'));
        $category_dropdown = array('0' => esc_html__('All Categories', 'woddingat-core'));

        foreach ($terms as $id => $name) {
            $category_dropdown[$id] = $name;
        }

		$fields = array(
			array(
				'id'      => 'sec_rt_team',
				'mode'    => 'section_start',
				'label'   => esc_html__( 'Team', 'woddingat-core' ),
			),
			array(
				'id'      => 'number',
				'label'   =>esc_html__( 'Total number of post', 'woddingat-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 4,
				'description' =>esc_html__( 'Write -1 to show all', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'id'      => 'orderby',
				'label'   => esc_html__( 'Order By', 'woddingat-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => array(
					'date'        => esc_html__( 'Date (Recents comes first)', 'woddingat-core' ),
					'title'       => esc_html__( 'Title', 'woddingat-core' ),
				),
				'default' => 'date',
				'label_block' => true,
			),
			array(
				'id'      => 'order',
				'label'   => esc_html__( 'Order', 'woddingat-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => array(
					'ASC' => __( 'Ascending Order', 'woddingat-core' ),
					'DESC' => __( 'Descending', 'woddingat-core' ),
				),
				'default' => 'DESC',
				'label_block' => true,
			),
			array(
                'type'     => Controls_Manager::SELECT2,
                'id'       => 'category_list',
                'label'    => esc_html__('Categories', 'woddingat-core'),
                'options'  => $category_dropdown,
                'default'  => '0',
                'multiple' => true,
            ),
			array(
				'type'    => Controls_Manager::SWITCHER,
				'id'      => 'social_showhide',
				'label'   => esc_html__( 'Social', 'woddingat-core' ),
				'label_on'    => esc_html__( 'Show', 'woddingat-core' ),
				'label_off'   => esc_html__( 'Hide', 'woddingat-core' ),
				'default'     => 'yes',
			),
			array(
				'type'    => Controls_Manager::SWITCHER,
				'id'      => 'cat_showhide',
				'label'   => esc_html__( 'Category', 'woddingat-core' ),
				'label_on'    => esc_html__( 'Show', 'woddingat-core' ),
				'label_off'   => esc_html__( 'Hide', 'woddingat-core' ),
				'default'     => 'yes',
			),		
			array(
				'mode' => 'section_end',
			),
			// Style
			array(
				'mode'    => 'section_start',
				'id'      => 'tab_style',
				'label'   => esc_html__( 'Tab', 'woddingat-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,				
			),
			array(
				'id'      => 'tab_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Normal', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'text_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .team-tab li a' => 'color: {{VALUE}}',
				),
			),
			array(
				'id'      => 'bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .team-tab li a' => 'background-color: {{VALUE}}',
				),
			),						
			array( 
					'mode'      => 'group',
					'type'      => Group_Control_Typography::get_type(),
					'name'      => 'text_typo',
					'label'     => esc_html__( 'Typography', 'woddingat-core' ),
					'selector'  => '{{WRAPPER}} .team-tab li a',
					
				),
			array(
				'id'      => 'tab_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'text_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .team-tab li a:hover' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'id'      => 'bg_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .team-tab li a:hover' => 'background-color: {{VALUE}}',
				),
			),
			array(
				'id'      => 'tab_a_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Active', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'text_a_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .team-tab li a.active' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'id'      => 'bg_a_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .team-tab li a.active' => 'background-color: {{VALUE}}',
				),
			),	
			array(
				'mode' => 'section_end',
			),
			// Social
			array(
				'mode'    => 'section_start',
				'id'      => 'social_style',
				'label'   => esc_html__( 'Social', 'woddingat-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,				
			),
			array(
				'id'      => 's_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .team-box.style-1 .social' => 'background-color: {{VALUE}}',
				),
			),
			array(
				'id'      => 'social_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Normal', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'icon_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Icon Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .team-box.style-1 .social li a' => 'color: {{VALUE}}',
				),
			),
			array(
				'id'      => 'icon_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .team-box.style-1 .social li a' => 'background-color: {{VALUE}}',
				),
			),						
			array( 
					'mode'      => 'group',
					'type'      => Group_Control_Typography::get_type(),
					'name'      => 'icon_typo',
					'label'     => esc_html__( 'Typography', 'woddingat-core' ),
					'selector'  => '{{WRAPPER}} .team-box.style-1 .social li a',
					
				),
			array(
				'id'      => 'social_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'icon_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .team-box.style-1 .social li a:hover' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'id'      => 'icon_bg_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .team-box.style-1 .social li a:hover' => 'background-color: {{VALUE}}',
				),
			),	
			array(
				'mode' => 'section_end',
			),
			//Title
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_title_style',
				'label'   => esc_html__( 'Title', 'woddingat-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,				
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .team-box.style-1 .content-box .title' => 'color: {{VALUE}}',
				),
			),						
			array( 
					'mode'      => 'group',
					'type'      => Group_Control_Typography::get_type(),
					'name'      => 'title_typo',
					'label'     => esc_html__( 'Title Typography', 'woddingat-core' ),
					'selector'  => '{{WRAPPER}} .team-box.style-1 .content-box .title',
					
				),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .team-box.style-1 .content-box .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .team-box.style-1 .content-box .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'mode'    => 'section_start',
				'id'      => 'sub_title_style',
				'label'   => esc_html__( 'Sub Title', 'woddingat-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,				
			),
			array(
				'id'      => 'sub_title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .team-box.style-1 .content-box .sub-title' => 'color: {{VALUE}}',
				),
			),						
			array( 
					'mode'      => 'group',
					'type'      => Group_Control_Typography::get_type(),
					'name'      => 'sub_title_typo',
					'label'     => esc_html__( 'Title Typography', 'woddingat-core' ),
					'selector'  => '{{WRAPPER}} .team-box.style-1 .content-box .sub-title',
					
				),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'sub_title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .team-box.style-1 .content-box .sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'sub_title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .team-box.style-1 .content-box .sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$template = 'view';

		return $this->rt_template( $template, $data );
	}
}