<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Testimonial extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Testimonial', 'woddingat-core' );
		$this->rt_base = 'rt-testimonial';
		parent::__construct( $data, $args );
	}

	public function rt_load_scripts(){
		wp_enqueue_style(  'slick');			
	    wp_enqueue_script( 'slick' );
	}

	public function rt_fields(){

		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'icon', [
				'type' => Controls_Manager::ICONS,
				'label'       => esc_html__( 'Icon', 'woddingat-core' ),
				'description' => esc_html__( 'Select icon', 'woddingat-core' ),
				'default'     => [
				      'value'   => 'flaticon-right-quote',
				      'library' => 'fa-solid',
				  	],
			]
		);
		$repeater->add_control(
			'title', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Title', 'woddingat-core' ),
				'default'     => esc_html__( 'ALICE JOHNSON', 'woddingat-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'designation', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Designation', 'woddingat-core' ),
				'default'     => esc_html__( 'Web Developer', 'woddingat-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'desc', [
				'type' 		  => Controls_Manager::TEXTAREA,
				'label'       => esc_html__( 'Description', 'woddingat-core' ),
				'default'     => esc_html__( 'Some people dream of success, while other people get up every morning and make it happen.', 'woddingat-core' ),
				'label_block' => true,
			]
		);
		$fields = array(
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_general',
				'label'   => esc_html__( 'General', 'woddingat-core' ),
			),
			array(
				'id'      	  => 'layout',
				'type'    	  => Controls_Manager::SELECT2,
				'label'   	  => esc_html__( 'Layout', 'woddingat-core' ),
				'options' 	  => array(
					'layout1' 	  => esc_html__( 'Layout 1', 'woddingat-core' ),
					'layout2' 	  => esc_html__( 'Layout 2', 'woddingat-core' ),
					'layout3' 	  => esc_html__( 'Layout 3', 'woddingat-core' ),
				),
				'default' 	  => 'layout1',
				'description' => esc_html__( 'Testimonial Layout. Default: Layout 1', 'woddingat-core' ),
				'label_block' => true,
			),
			array (
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'testimonials',
				'label'   => esc_html__( 'Items', 'woddingat-core' ),
				'fields' => $repeater->get_controls(),
				'default'  => [
					[
						'icon'  => 'flaticon-right-quote',
						'title' => __( 'ALICE JOHNSON', 'woddingat-core' ),
						'desc'  => __( 'Some people dream of success, while other people get up every morning and make it happen.', 'woddingat-core' ),
					],
					[
						'icon'  => 'flaticon-right-quote',
						'title' => __( 'ALICE JOHNSON', 'woddingat-core' ),
						'desc'  => __( 'Some people dream of success, while other people get up every morning and make it happen.', 'woddingat-core' ),
					],
					[
						'icon'  => 'flaticon-right-quote',
						'title' => __( 'ALICE JOHNSON', 'woddingat-core' ),
						'desc'  => __( 'Some people dream of success, while other people get up every morning and make it happen.', 'woddingat-core' ),
					],
					[
						'icon'  => 'flaticon-right-quote',
						'title' => __( 'ALICE JOHNSON', 'woddingat-core' ),
						'desc'  => __( 'Some people dream of success, while other people get up every morning and make it happen.', 'woddingat-core' ),
					],
				],
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'mode'        => 'section_start',
				'id'          => 'sec_slider',
				'label'       => esc_html__( 'Slider Options', 'woddingat-core' ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_autoplay',
				'label'       => esc_html__( 'Autoplay', 'woddingat-core' ),
				'label_on'    => esc_html__( 'On', 'woddingat-core' ),
				'label_off'   => esc_html__( 'Off', 'woddingat-core' ),
				'description' => esc_html__( 'Enable or disable autoplay. Default: On', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slider_autoplay_speed',
				'label'   => esc_html__( 'Autoplay Speed', 'woddingat-core' ),
				'options' => $this->rt_autoplay_speed(),
				'default' => '2000',
				'description' => esc_html__( 'Select any value for autopaly speed. Default: 2000', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slide_to_show',
				'label'   => esc_html__( 'Slide To Show', 'woddingat-core' ),
				'options' => $this->rt_number_options(),
				'default' => '2',
				'description' => esc_html__( 'Select any value for desktop device show. Default: 2', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slide_to_show_tab',
				'label'   => esc_html__( 'Tab View', 'woddingat-core' ),
				'options' => $this->rt_number_options(),
				'default' => '2',
				'description' => esc_html__( 'Select any value for tab device show. Default: 2', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slide_to_show_mobile',
				'label'   => esc_html__( 'Mobile View', 'woddingat-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'Select any value for mobile device show. Default: 1', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slide_to_show_small_mobile',
				'label'   => esc_html__( 'Mobile Small View', 'woddingat-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'Select any value for small mobile device show. Default: 1', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'mode' => 'section_end',
			),
			// Icon Styles
			array(
				'id'      => 'testi_icon_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Icon', 'woddingat-core' ),
			),
			array(
				'id'        => 'icon_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .testimonial-box-layout1 .icon' => 'color: {{VALUE}}',  
					'{{WRAPPER}} .testimonial-box-layout2 .icon' => 'color: {{VALUE}}',  
					'{{WRAPPER}} .testimonial-box-layout3 .icon' => 'color: {{VALUE}}',  
				),
			),
			array(
				'name'      => 'icon_typo',
				'mode'      => 'group',
				'type'      => Group_Control_Typography::get_type(),
				'label'     => esc_html__( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .testimonial-box-layout1 .icon, {{WRAPPER}} .testimonial-box-layout2 .icon, {{WRAPPER}} .testimonial-box-layout3 .icon',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'icon_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .testimonial-box-layout1 .icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	                '{{WRAPPER}} .testimonial-box-layout2 .icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	                '{{WRAPPER}} .testimonial-box-layout3 .icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'icon_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .testimonial-box-layout1 .icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .testimonial-box-layout2 .icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .testimonial-box-layout3 .icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'sec_title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'woddingat-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .testimonial-box-layout1 .name' => 'color: {{VALUE}}',  
					'{{WRAPPER}} .testimonial-box-layout2 .name' => 'color: {{VALUE}}',  
					'{{WRAPPER}} .testimonial-box-layout3 .name' => 'color: {{VALUE}}',  
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .testimonial-box-layout1 .title, {{WRAPPER}} .testimonial-box-layout2 .name, {{WRAPPER}} .testimonial-box-layout3 .name',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .testimonial-box-layout1 .name' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	                '{{WRAPPER}} .testimonial-box-layout2 .name' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	                '{{WRAPPER}} .testimonial-box-layout3 .name' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .testimonial-box-layout1 .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .testimonial-box-layout2 .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .testimonial-box-layout3 .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'designation_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Designation', 'woddingat-core' ),
				'condition' => array( 'layout' => array( 'layout2', 'layout3' ) ),
			),
			array(
				'id'      => 'designation_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .testimonial-box-layout2 .designation' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .testimonial-box-layout3 .designation' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'designation_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .testimonial-box-layout2 .designation, {{WRAPPER}} .testimonial-box-layout3 .designation',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'designation_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .testimonial-box-layout2 .designation' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	                '{{WRAPPER}} .testimonial-box-layout3 .designation' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'designation_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .testimonial-box-layout2 .designation' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .testimonial-box-layout3 .designation' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'content_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Content', 'woddingat-core' ),
			),
			array(
				'id'      => 'content_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .testimonial-box-layout1 .title' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .testimonial-box-layout2 .title' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .testimonial-box-layout3 .title' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'content_typo',
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .testimonial-box-layout1 .title, {{WRAPPER}} .testimonial-box-layout2 .title, {{WRAPPER}} .testimonial-box-layout3 .title',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'content_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .testimonial-box-layout1 .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	                '{{WRAPPER}} .testimonial-box-layout2 .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	                '{{WRAPPER}} .testimonial-box-layout3 .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'content_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .testimonial-box-layout1 .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .testimonial-box-layout2 .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .testimonial-box-layout3 .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			// Border
			array(
				'id'      => 'border_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Border', 'woddingat-core' ),
				'condition' => array( 'layout' => array( 'layout1', 'layout2' ) ),
			),
			array(
				'id'      => 'border_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .testimonial-box-layout1 .name:before' => 'background-color: {{VALUE}}', 
					'{{WRAPPER}} .testimonial-box-layout1 .name:after' => 'background-color: {{VALUE}}', 
					'{{WRAPPER}} .testimonial-wrap-layout2:before' => 'background-color: {{VALUE}}', 
				),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$this->rt_load_scripts();

		switch ( $data['layout'] ) {
			case 'layout3':
			$template = 'view-3';
			break;
			case 'layout2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}