<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Background;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit;

class Title extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = esc_html__( 'Title', 'woddingat-core' );
		$this->rt_base = 'rt-title';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_general',
				'mode'    => 'section_start',
				'label'   => esc_html__( 'General', 'woddingat-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'woddingat-core' ),
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'woddingat-core' ),
					'style2' => esc_html__( 'Style 2', 'woddingat-core' ),
					'style3' => esc_html__( 'Style 3', 'woddingat-core' ),
					'style4' => esc_html__( 'Style 4', 'woddingat-core' ),
					'style5' => esc_html__( 'Style 5', 'woddingat-core' ),
					'style6' => esc_html__( 'Style 6', 'woddingat-core' ),
				),
				'default' => 'style1',
				'label_block' => true,
			),
			/*Icon Start*/
			array(					 
			   'type'    => Controls_Manager::CHOOSE,
			   'options' => array(
			     'icon' => array(
			       'title' => esc_html__( 'Left', 'woddingat-core' ),
			       'icon' => 'fa fa-smile-o',
			     ),
			     'image' => array(
			       'title' => esc_html__( 'Center', 'woddingat-core' ),
			       'icon' => 'fa fa-image',
			     ),		     
			   ),
			   'id'      => 'icontype',
			   'label'   => esc_html__( 'Media Type', 'woddingat-core' ),
			   'default' => 'icon',
			   'label_block' => false,
			   'toggle' => false,
			   'condition' => array( 'style' => array( 'style3' ) ),
			),
			array(
            	'type'    => Controls_Manager::CHOOSE,
				'mode'	  => 'responsive',
				'id'      => 'alignment',
				'label'   => esc_html__( 'Alignment', 'fwoddingat-core' ),
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'woddingat-core' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'woddingat-core' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'woddingat-core' ),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .section-heading' => 'text-align: {{VALUE}};',
                ],
				'default' => 'center',
            ),
			array(
				'type'    => Controls_Manager::ICONS,
				'id'      => 'icon_class',
				'label'   => esc_html__( 'Icon', 'woddingat-core' ),
				'default' => array(
			      'value' => 'fas fa-smile-wink',
			      'library' => 'fa-solid',
			  ),	
			  	'condition'   => array(
			  		'icontype' => array( 'icon' ), 
			  		'style' => array( 'style3' ), 
			  	),
			),	
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'icon_image',
				'label'   => esc_html__( 'Image', 'woddingat-core' ),
				'default' => array(
                    'url' => Utils::get_placeholder_image_src(),
                ),
                'description' => esc_html__( 'Recommended full image', 'woddingat-core' ),
				'condition'   => array(
					'icontype' => array( 'image' ),
					'style' => array( 'style3' ), 
				),
			),
			array(
				'type'    => Group_Control_Image_Size::get_type(),
				'mode'    => 'group',				
				'label'   => esc_html__( 'image size', 'woddingat-core' ),	
				'name' => 'icon_image_size', 
				'separator' => 'none',		
				'condition'   => array(
					'icontype' => array( 'image' ),
					'style' => array( 'style3' ), 
				),
			),
			array(
				'id'      => 'title',
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title', 'woddingat-core' ),
				'default' => esc_html__( 'Section Title', 'woddingat-core' ),
				'label_block' => true,
			),
			array(
				'id'      => 'sub_title',
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Sub Title', 'woddingat-core' ),
				'default' => esc_html__( 'Sub title', 'woddingat-core' ),
				'label_block' => true,
				'condition' => array( 'style' => array( 'style2' ) ),
			),
			array(
				'type'        => Controls_Manager::TEXT,
				'id'          => 'btntext',
				'label'       => esc_html__( 'Link Text', 'woddingat-core' ),
				'default'     => esc_html__( '@ My_wedding_day', 'woddingat-core' ),
				'label_block' => true,
				'condition' => array( 'style' => array( 'style5' ) ),
			),
			array(
				'type'        => Controls_Manager::URL,
				'id'          => 'url',
				'label'       => esc_html__( 'Link (Optional)', 'woddingat-core' ),
				'placeholder' => 'https://your-link.com',
				'condition' => array( 'style' => array( 'style5' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXTAREA,
				'id'      => 'description',
				'label'   => esc_html__( 'Description', 'woddingat-core' ),
				'default' => esc_html__( 'Grursus mal suada faci lisis Lorem ipsum dolarorit more a ametion consectetur elit. Ipsumm and dum fadolorit to the consectetur elit.', 'woddingat-core' ),
				'condition' => array( 'style' => array( 'style1', 'style2', 'style3', 'style6' ) ),
			),
			array(
				'id'      => 'description_width',
				'type' => Controls_Manager::SLIDER,
				'label'   => esc_html__( 'Description Width', 'woddingat-core' ),
				'size_units' => [ 'px', '%' ],
				'mode' => 'responsive',
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1170,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					]
				],
				'default' => [
					'unit' => 'px',
					'size' => 650,
				],
				'selectors' => [
					'{{WRAPPER}} .section-heading.style-2 .description' => 'max-width: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .section-heading.style-4 .description' => 'max-width: {{SIZE}}{{UNIT}};',
				],
				'condition' => array( 'style' => array( 'style1', 'style2', 'style3' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			// Style
			array(
				'id'      => 'sec_title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Title', 'woddingat-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-heading.style-2 .title' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .section-heading.style-3 .title' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .section-heading.style-4 .title' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .section-heading.style-5 .title' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .section-heading.style-6 .title' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .section-heading.progress-sh.style-6 .title' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => esc_html__( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .section-heading.style-2 .title, {{WRAPPER}} .section-heading.style-3 .title, {{WRAPPER}} .section-heading.style-4 .title, {{WRAPPER}} .section-heading.style-5 .title, {{WRAPPER}} .section-heading.style-6 .title, {{WRAPPER}} .section-heading.progress-sh.style-6 .title',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .section-heading.style-2 .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .section-heading.style-3 .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .section-heading.style-4 .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .section-heading.style-5 .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .section-heading.style-6 .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .section-heading.progress-sh.style-6 .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .section-heading.style-2 .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .section-heading.style-3 .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .section-heading.style-4 .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .section-heading.style-5 .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .section-heading.style-6 .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .section-heading.progress-sh.style-6 .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'sub_title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Sub Title', 'woddingat-core' ),
				'condition'	  => array( 'style' => array( 'style2')),
			),
			array(
				'id'      => 'sub_title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-heading.style-3 .sub-title' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'sub_title_typo',
				'label'    => esc_html__( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .section-heading.style-3 .sub-title',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'sub_title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'woddingat-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .section-heading.style-3 .sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'sub_title_margin',
	            'label'   => esc_html__( 'Margin', 'woddingat-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .section-heading.style-3 .sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'content_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Content', 'woddingat-core' ),
				'condition' => array( 'style' => array( 'style1', 'style2', 'style3', 'style6' ) ),
			),
			array(
				'id'      => 'content_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-heading.style-2 .description' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .section-heading.style-3 .description' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .section-heading.style-4 .description' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .section-heading.progress-sh.style-6 .description' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'content_typo',
				'label'    => esc_html__( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .section-heading.style-2 .description, {{WRAPPER}} .section-heading.style-3 .description, {{WRAPPER}} .section-heading.style-4 .description, {{WRAPPER}} .section-heading.progress-sh.style-6 .description',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'icon_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Icon', 'woddingat-core' ),
				'condition'   => array(
			  		'icontype' => array( 'icon' ), 
			  		'style' => array( 'style3' ), 
			  	),
			),
			array(
				'id'      => 'icon_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-heading.style-4 span.rtin-icon' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'icon_typo',
				'label'    => esc_html__( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .section-heading.style-4 span.rtin-icon',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'link_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Link', 'woddingat-core' ),
				'condition'	  => array( 'style' => array( 'style5')),
			),
			array(
				'id'      => 'link_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Normal', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'link_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-heading.style-6 .sub-title a' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'link_typo',
				'label'    => esc_html__( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .section-heading.style-6 .sub-title a',
			),
			array(
				'id'      => 'link_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'link_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'woddingat-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-heading.style-6 .sub-title a:hover' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode' => 'section_end',
			),

		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ($data['style']) {
			case 'style6':
			$template = 'view-6';
			break;
			case 'style5':
			$template = 'view-5';
			break;
			case 'style4':
			$template = 'view-4';
			break;
			case 'style3':
			$template = 'view-3';
			break;
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}