<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Video_Button extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Video Button', 'woddingat-core' );
		$this->rt_base = 'rt-video-button';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'video_button',
				'mode'    => 'section_start',
				'label'   => __( 'Video Button', 'woddingat-core' ),
			),
			// Background Image
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'bg_image',
				'label'   => esc_html__( 'Background Image', 'woddingat-core' ),
				'default' => [
	                'url' => $this->rt_placeholder_image(),
	            ],
				'description' => esc_html__( 'Recommended full image', 'woddingat-core' ),
			),
			array(
				'id'      => 'video_link',
				'type'    => Controls_Manager::TEXT,
				'label'   => __( 'Video link', 'woddingat-core' ),
				'default' => 'https://www.youtube.com/watch?v=1iIZeIy7TqM',
			),
			array(
				'type'    => Controls_Manager::ICONS,
				'id'      => 'video_icon',
				'label'   => esc_html__( 'Video play icon', 'woddingat-core' ),
				'default' => [
				    'value' => 'fas fa-play',
				    'library' => 'fa-solid',
				],
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'sec_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Button Style', 'woddingat-core' ),
			),
			array(
				'id'      => 'btn_font_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .video-box-layout1 .play-btn.style-3' => 'color: {{VALUE}}',
				),
			),
			array(
				'name'     => 'icon_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .video-box-layout1 .play-btn.style-3',
			),
			array(
				'name'       => 'btnh_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'woddingat-core' ),
				'selector' => '{{WRAPPER}} .video-box-layout1 .play-btn.style-3:after',
			),
			array(
				'id'      => 'hover_hover_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover Style', 'woddingat-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'btn_hfont_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .video-box-layout1 .play-btn.style-3:hover' => 'color: {{VALUE}}',
				),
			),
			array(
				'id'      => 'btn_bg',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background', 'woddingat-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .video-box-layout1 .play-btn.style-3:before' => 'background-color: {{VALUE}}',
				),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$template = 'view';

		return $this->rt_template( $template, $data );
	}
}