<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;

use \WP_Widget;
use \RT_Widget_Fields;
use radiustheme\Woddingat\inc\Helper;
use radiustheme\woddingat\inc\RDTheme;

class About_Author extends WP_Widget {
	public function __construct() {
		$id = WODDINGAT_CORE_THEME_PREFIX . '_about_author';
		parent::__construct(
            $id, // Base ID
            esc_html__( 'Woddingat: Author About', 'woddingat-core' ), // Name
            array( 'description' => esc_html__( 'Woddingat: Author About Widget', 'woddingat-core' )
        ) );
	}

	public function widget( $args, $instance ){

		echo wp_kses_post( $args['before_widget'] );

		$title = $instance['title'];
		if( !empty( $instance['author_img'] ) ){
		    $img = wp_get_attachment_image( $instance['author_img'], 'full' );
		}else{
		    $img = Helper::get_img( 'author-img.jpg' );
		    $img = "<img width='250' height='250' src='". esc_url( $img ) ."' alt='". esc_attr( get_bloginfo( 'name' ) ). "'>";
		}
		$desc  = $instance['desc'];

	    ?>
	    <div class="widget-author">
	    	<?php if( !empty( $img ) ) : ?>
			<figure>
				 <?php echo wp_kses( $img, 'alltext_allow' ); ?>
			</figure>
			<?php endif; ?>
			<div class="content-box">
				<?php if( !empty( $title ) ) : ?>
				<h3 class="title"><?php echo wp_kses_post( $title ); ?></h3>
				<?php endif; if( !empty( $desc ) ) : ?>
				<p class="description"><?php echo wp_kses_post( $desc ); ?></p>
				<?php endif; ?>
			</div>
		</div>

        <?php 
		echo wp_kses_post( $args['after_widget'] );
	}

	public function update( $new_instance, $old_instance ){
		$instance          = array();

		$instance['title']  = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';

		$instance['author_img']  = ( ! empty( $new_instance['author_img'] ) ) ? sanitize_text_field( $new_instance['author_img'] ) : '';

		$instance['desc'] = ( ! empty( $new_instance['desc'] ) ) ? sanitize_text_field( $new_instance['desc'] ) : '';

		return $instance;
	}

	public function form( $instance ){
		$defaults = array(
			'title'      => '',
			'author_img' => '',
			'desc'	     => '',
			'socials'    => '',
		);
		$instance = wp_parse_args( (array) $instance, $defaults );

		$fields = array(
			'title'       => array(
				'label'   => esc_html__( 'Title', 'woddingat-core' ),
				'type'    => 'text',
			),
			'author_img'  => array(
				'label'   => esc_html__( 'Image', 'woddingat-core' ),
				'type'    => 'image',
			),
			'desc'        => array(
				'label'   => esc_html__( 'Description', 'woddingat-core' ),
				'type'    => 'textarea',
			),
		);

		RT_Widget_Fields::display( $fields, $instance, $this );
	}
}