<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Woddingat_Core;

use \WP_Widget;
use \RT_Widget_Fields;
use radiustheme\Woddingat\Helper;

class Contact_Widget extends WP_Widget {
	public function __construct() {
		$id = WODDINGAT_CORE_THEME_PREFIX . '_contact';
		parent::__construct(
            $id, // Base ID
            esc_html__( 'Woddingat: Footer Contact', 'woddingat-core' ), // Name
            array( 'description' => esc_html__( 'Woddingat: Footer Contact Widget', 'woddingat-core' )
        ) );
	}

	public function widget( $args, $instance ){

		echo wp_kses_post( $args['before_widget'] );
		if ( ! empty( $instance['title'] ) ) {
			echo wp_kses_post( $args['before_title'] ) . apply_filters( 'widget_title', esc_html( $instance['title'] ) ) . wp_kses_post( $args['after_title'] );
		}
		?>

		<?php
		if( !empty( $instance['address'] ) ){ ?>
		<div class="d-flex justify-content-center">
			<div class="footer-address">
				<div class="icon-box">
					<i class="flaticon-map-locator"></i>
				</div>
				<p class="description"><?php echo wp_kses_post( $instance['address'] ); ?></p>
			</div>
		</div>
		<?php } ?>
		<?php if( !empty( $instance['email'] || !empty( $instance['phone'] ) ) ){ ?>
		<div class="d-flex justify-content-center">
			<div class="footer-contact">
				<ul class="block-list">
			<?php if( !empty( $instance['email'] ) ){ ?>
				<li>
					<span><?php esc_html_e( 'Mail Us:', 'woddingat' ); ?></span>
					<a href="mailto:<?php echo esc_attr( $instance['email'] ); ?>">
						<?php echo esc_html( $instance['email'] ); ?>
					</a>
				</li>
			<?php }
			if( !empty( $instance['phone'] ) ){ ?>
				<li>
					<span><?php esc_html_e( 'Phone No:', 'woddingat' ); ?></span>
					<a href="tel:<?php echo esc_attr( str_replace(' ', '', $instance['phone'] ) ); ?>">
						<?php echo esc_html( $instance['phone'] ); ?>
					</a>
				</li>
			<?php } ?>
				</ul>
			</div>
		</div>
		<?php } ?>
		<?php
		echo wp_kses_post( $args['after_widget'] );
	}

	public function update( $new_instance, $old_instance ){
		$instance              = array();
		$instance['title']     = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
		$instance['phone']     = ( ! empty( $new_instance['phone'] ) ) ? sanitize_text_field( $new_instance['phone'] ) : '';
		$instance['email']     = ( ! empty( $new_instance['email'] ) ) ? sanitize_email( $new_instance['email'] ) : '';
		$instance['address']   = ( ! empty( $new_instance['address'] ) ) ? wp_kses_post( $new_instance['address'] ) : '';
		return $instance;
	}

	public function form( $instance ){
		$defaults = array(
			'title'   => esc_html__( 'Contact Us' , 'woddingat-core' ),
			'phone'   => '',
			'email'   => '',
			'address' => '',
		);
		$instance = wp_parse_args( (array) $instance, $defaults );

		$fields = array(
			'title'     => array(
				'label' => esc_html__( 'Title', 'woddingat-core' ),
				'type'  => 'text',
			),
			'address'   => array(
				'label' => esc_html__( 'Address', 'woddingat-core' ),
				'type'  => 'textarea',
			),
			'email'     => array(
				'label' => esc_html__( 'Email', 'woddingat-core' ),
				'type'  => 'text',
			),
			'phone'     => array(
				'label' => esc_html__( 'Phone', 'woddingat-core' ),
				'type'  => 'text',
			),		
		);

		RT_Widget_Fields::display( $fields, $instance, $this );
	}
}